@@ -12,17 +12,41 @@
 class BehaviorBase : public ReferenceCounter, public EventListener {
  public:
 	//! constructor
-	BehaviorBase() : ReferenceCounter(), started(false) {}
+	BehaviorBase() : ReferenceCounter(), EventListener(), started(false) {}
+	//! copy constructor; assumes subclass handles copying approriately - i.e. if @a b is active, the copy will be as well, even though DoStart was never called..
+	BehaviorBase(const BehaviorBase& b) : ReferenceCounter(b), EventListener(b), started(b.started) {}
+	//! assignment operator; assumes subclass handles assignment appropriately - i.e. if @a b is active, the copy will be as well, even though DoStart was never called..
+	BehaviorBase& operator=(const BehaviorBase& b) { ReferenceCounter::operator=(b); EventListener::operator=(b); started=b.started; return *this; }
+
 	//! destructor - if is active when deleted, will call DoStop() first
-	virtual ~BehaviorBase() { SetAutoDelete(false); if(started) DoStop();  } //{ if(started) { references++; DoStop(); references--; } }
+	virtual ~BehaviorBase() {
+		SetAutoDelete(false);
+		if(started)
+			DoStop();
+		//{ if(started) { references++; DoStop(); references--; } }
+	}
+	
 	//! By default, merely adds to the reference counter (through AddReference()) @note you should still call this from your overriding methods
-	virtual void DoStart() { if(!started) { started=true; AddReference(); } }
+	virtual void DoStart() {
+		//std::cout << getName() << " started " << this << std::endl;
+		if(!started) {
+			started=true;
+			AddReference();
+		}
+	}
+
 	//! By default, subtracts from the reference counter, and deletes if zero @note you should still call this when you override this @warning call this at the end of your DoStop(), not beginning (it might @c delete @c this )
-	virtual void DoStop() { if(started) { started=false; RemoveReference(); } }
-	//! Allows you to get away with not supplying a processEvent() function for the EventListener interface.  By default, does nothing.
+	virtual void DoStop() {
+		//std::cout << getName() << " stopped " << this << std::endl;
+		if(started) {
+			started=false;
+			RemoveReference();
+		}
+	}
+	
+	//! By defining here, allows you to get away with not supplying a processEvent() function for the EventListener interface.  By default, does nothing.
 	virtual void processEvent(const EventBase& /*event*/) {};
 
-	
 	//! Identifies the behavior in menus and such
 	virtual std::string getName() const =0;
 
@@ -44,10 +68,10 @@ class BehaviorBase : public ReferenceCounter, public EventListener {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.5 $
- * $State: Exp $
- * $Date: 2003/06/09 08:05:08 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.9 $
+ * $State: Rel $
+ * $Date: 2003/10/10 15:54:04 $
  */
 
 #endif
