@@ -24,11 +24,15 @@
  *	- '<tt>!select</tt>' - calls ControlBase::doSelect() of the current control
  *	- '<tt>!cancel</tt>' - calls ControlBase::doCancel() of the current control
  *	- '<tt>!msg </tt><i>text</i>' - broadcasts <i>text</i> as a TextMsgEvent
+ *  - '<tt>!root </tt><i>text</i>' - calls ControlBase::takeInput(<i>text</i>) on the root control
+ *  - '<tt>!hello</tt>' - responds with '<tt>hello\n</tt><i>count</i>' where <i>count</i> is the number of times '<tt>!hello</tt>' has been sent.  Good for detecting first connection after boot vs. a reconnect.
  *	- '<tt>!hilight</tt> [<i>n1</i> [<i>n2</i> [...]]]' - hilights zero, one, or more items in the menu
  *	- '<tt>!input </tt><i>text</i>' - calls ControlBase::takeInput(<i>text</i>) on the currently hilighted control(s)
  *	- any text not beginning with '!' - sent to ControlBase::takeInput() of the current control
  *
  *  In return, to send the menus to the GUI, the following messages are sent: (newlines are required where shown)
+ *  - '<tt>push</tt>' - signals a submenu has been activated
+ *  - '<tt>pop</tt>' - signals a submenu has been closed
  *  - '<tt>refresh</tt>\n
  *    <i>text:title</i>\n
  *    <i>int:numitems</i>\n
@@ -81,10 +85,11 @@
 class Controller : public BehaviorBase, public EventTrapper {
  public:
 	Controller() : display(MotionManager::invalid_MC_ID), estop_id(MotionManager::invalid_MC_ID), root(NULL), cmdstack(), last_time(0), cur_time(0), nextEv_val(0), nextEv_dur(0), prevEv_val(0), prevEv_dur(0), alreadyGotBoth(false), gui_comm(wireless->socket(SocketNS::SOCK_STREAM, 2048, 2048))  {init();}	//!< Constructor
-	Controller(ControlBase* r) : display(MotionManager::invalid_MC_ID), estop_id(MotionManager::invalid_MC_ID), root(r), cmdstack(), last_time(0), cur_time(0), nextEv_val(0), nextEv_dur(0), prevEv_val(0), prevEv_dur(0), alreadyGotBoth(false), gui_comm(wireless->socket(SocketNS::SOCK_STREAM, 2048, 2048)) {init();} //!< Constructor, sets a default root control
+	Controller(ControlBase* r) : display(MotionManager::invalid_MC_ID), estop_id(MotionManager::invalid_MC_ID), root(r), cmdstack(), last_time(0), cur_time(0), nextEv_val(0), nextEv_dur(0), prevEv_val(0), prevEv_dur(0), alreadyGotBoth(false), gui_comm(wireless->socket(SocketNS::SOCK_STREAM, 2048, 2048)) { init(); } //!< Constructor, sets a default root control
 	virtual ~Controller() {
 		cout << "~Controller()..." << endl;
 		delete root;
+		theOneController=NULL;
 		cout << "~Controller()-DONE" << endl;
 	} //!< Destructor
 
@@ -171,10 +176,6 @@ class Controller : public BehaviorBase, public EventTrapper {
 		return (lastclock!=nextclock);
 	}
 
-	static std::string makeLower(const std::string& s); //!< returns lower case version of @a s
-	static std::string removePrefix(const std::string& str, const std::string& pre); //!< returns @a str with @a pre removed - if @a pre is not fully matched, @a str is returned unchanged
-
-
 
 	unsigned int last_time; //!< the time of the last event
 	unsigned int cur_time; //!< the time of the current event (do*() can check this instead of calling get_time() )
@@ -197,10 +198,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.16 $
- * $State: Exp $
- * $Date: 2003/07/08 18:01:21 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.21 $
+ * $State: Rel $
+ * $Date: 2003/09/09 21:10:01 $
  */
 
 #endif
