@@ -7,6 +7,7 @@
 #include "Motion/MMAccessor.h"
 #include "Motion/LedMC.h"
 #include "NullControl.h"
+#include "Events/EventRouter.h"
 
 //! when activated, this will print a battery report to stdout and light up LEDs to specify power level
 /*! The LEDs use the LedEngine::displayPercent() function, with minor/major style.  This means
@@ -33,7 +34,7 @@ public:
 	//!Prints a report to stdio and lights up the face to show battery level
 	/*! keeps running until deactivated - will listen for power events and continue to update display */
 	virtual ControlBase * activate(MotionManager::MC_ID display, Socket * gui) {
-		cout << "Press the \"back\" button to leave battery display" << endl;
+		sout->printf("Press the \"back\" button to leave battery display\n");
 		erouter->addListener(this,EventBase::powerEGID);
 		return ControlBase::activate(display,gui);
 	}
@@ -72,30 +73,30 @@ public:
 	virtual ControlBase * doSelect() {
 		return this;
 	}
-	//! redisplay text to cout and refresh LED values
+	//! redisplay text to sout and refresh LED values
 	void report() {
-		cout << "BATTERY REPORT:" << endl;
-		cout << "\tPower Remain:\t" << (int)(state->sensors[PowerRemainOffset]*100) << "%" << endl;
-		cout << "\tCapacity:\t" << state->sensors[PowerCapacityOffset] << endl;
-		cout << "\tVoltage:\t" << state->sensors[PowerVoltageOffset] << endl;
-		cout << "\tCurrent:\t" << state->sensors[PowerCurrentOffset] << endl;
-		cout << "\tTemp:\t" << state->sensors[PowerThermoOffset] << endl;
-		cout << "\tFlags:\t";
+		sout->printf("BATTERY REPORT:\n");
+		sout->printf("\tPower Remain:\t%d%%\n",(int)(state->sensors[PowerRemainOffset]*100));
+		sout->printf("\tCapacity:\t%d\n",state->sensors[PowerCapacityOffset]);
+		sout->printf("\tVoltage:\t%g\n",state->sensors[PowerVoltageOffset]);
+		sout->printf("\tCurrent:\t%d\n",state->sensors[PowerCurrentOffset]);
+		sout->printf("\tTemperature:\t%g\n",state->sensors[PowerThermoOffset]);
+		sout->printf("\tFlags:\t");
 		if(state->powerFlags[PowerSourceID::BatteryConnectSID])
-			cout << "BatteryConnect ";
+			sout->printf("BatteryConnect ");
 		if(state->powerFlags[PowerSourceID::DischargingSID])
-			cout << "Discharging ";
+			sout->printf("Discharging ");
 		if(state->powerFlags[PowerSourceID::ChargingSID])
-			cout << "Charging ";
+			sout->printf("Charging ");
 		if(state->powerFlags[PowerSourceID::ExternalPowerSID])
-			cout << "ExternalPower ";
+			sout->printf("ExternalPower ");
 		if(state->powerFlags[PowerSourceID::PowerGoodSID])
-			cout << "PowerGood ";
+			sout->printf("PowerGood ");
 		if(state->powerFlags[PowerSourceID::LowPowerWarnSID])
-			cout << "LowPowerWarn ";
+			sout->printf("LowPowerWarn ");
 		if(state->powerFlags[PowerSourceID::BatteryEmptySID])
-			cout << "BatteryEmpty ";
-		cout << endl;
+			sout->printf("BatteryEmpty ");
+		sout->printf("\n");
 		if(display_id!=MotionManager::invalid_MC_ID) {
 			MMAccessor<LedMC> disp(display_id);
 			disp->displayPercent(state->sensors[PowerRemainOffset],LedEngine::major,LedEngine::major);
@@ -109,10 +110,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.4 $
- * $State: Exp $
- * $Date: 2003/06/09 08:05:12 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.7 $
+ * $State: Rel $
+ * $Date: 2003/07/26 01:48:03 $
  */
 
 #endif
