@@ -1,6 +1,7 @@
 #include "ControlBase.h"
 #include "Motion/MMAccessor.h"
 #include "Motion/LedMC.h"
+#include "Shared/string_util.h"
 #include "Wireless/Wireless.h"
 #include <iomanip>
 #include <sstream>
@@ -22,12 +23,14 @@ void ControlBase::pause() {
 void ControlBase::refresh() {
 	//Level 1: LEDs
 	if(display_id!=MotionManager::invalid_MC_ID) {
-		MMAccessor<LedMC> display(display_id);
-		unsigned int cur=hilights.front();
-		if(options.size()<=10)
-			display.mc()->displayNumber(cur,LedEngine::onedigit);
-		else
-			display.mc()->displayNumber(cur,LedEngine::twodigit);
+		if(hilights.size()>0) {
+			MMAccessor<LedMC> display(display_id);
+			unsigned int cur=hilights.front();
+			if(options.size()<=10)
+				display.mc()->displayNumber(cur,LedEngine::onedigit);
+			else
+				display.mc()->displayNumber(cur,LedEngine::twodigit);
+		}
 	}
 
 	//Just do one of the other two levels to avoid over-redundancy
@@ -59,28 +62,27 @@ void ControlBase::refresh() {
 		doRewrite=true;
 	} else {
 		//Level 3: GUI
-		if(gui_comm!=NULL && wireless->isConnected(gui_comm->sock)) {
-			//		cout << "REFRESHING " << getName() << endl;
-			//try to get it all in one packet for better performance
-			std::stringstream ss;
-			ss << "refresh\n"
-				 << getName() << '\n'
-				 << options.size() << '\n';
-			for(unsigned int i=0; i<options.size(); i++)
-				if(options[i]==NULL)
-					ss << "0\n0\n----------\n\n";
-				else 
-					ss << options[i]->options.size() << '\n'
-						 << (binary_search(hilights.begin(),hilights.end(),i)?1:0) << '\n'
-						 << options[i]->getName() << '\n'
-						 << options[i]->getDescription().c_str() << '\n';
-			//		do {
-			//cout << "Writing " << ss.str().size() << "...";
-			gui_comm->write((const byte*)ss.str().c_str(),ss.str().size());
-			//		int cnt=gui_comm->printf("%s",(const byte*)ss.str().c_str());
-			//cout << "wrote " << cnt << endl;
-			//} while(cnt==-1);
-		}
+
+		//		cout << "REFRESHING " << getName() << endl;
+		//try to get it all in one packet for better performance
+		std::stringstream ss;
+		ss << "refresh\n"
+			 << getName() << '\n'
+			 << options.size() << '\n';
+		for(unsigned int i=0; i<options.size(); i++)
+			if(options[i]==NULL)
+				ss << "0\n0\n----------\n\n";
+			else 
+				ss << options[i]->options.size() << '\n'
+					 << (binary_search(hilights.begin(),hilights.end(),i)?1:0) << '\n'
+					 << options[i]->getName() << '\n'
+					 << options[i]->getDescription().c_str() << '\n';
+		//		do {
+		//cout << "Writing " << ss.str().size() << "...";
+		gui_comm->write((const byte*)ss.str().c_str(),ss.str().size());
+		//		int cnt=gui_comm->printf("%s",(const byte*)ss.str().c_str());
+		//cout << "wrote " << cnt << endl;
+		//} while(cnt==-1);
 	}
 }
 
@@ -211,7 +213,86 @@ ControlBase* ControlBase::doReadStdIn(const std::string& prompt/*=std::string()*
 }
 
 ControlBase* ControlBase::takeInput(const std::string& str) {
-	std::string msg;
+	std::vector<std::string> args;
+	std::vector<unsigned int> offsets;
+	if(!string_util::parseArgs(str,args,offsets)) {
+		serr->printf("ControlBase::takeInput(\"%s\") was not understood.\n",str.c_str());
+		refresh();
+		return this;
+	} else {
+		//are there valid arguments?
+		if(args.size()==0) {
+			refresh();
+			return this;
+		}
+		//let's see if the first arg matches an option name (case sensitive)
+		unsigned int choice=-1U;
+		bool ambiguous=false;
+		for(unsigned int i=0; i<options.size(); i++) {
+			if(options[i]!=NULL && options[i]->name.compare(0,args[0].size(),args[0])==0) {
+				if(choice==-1U)
+					choice=i;
+				else
+					ambiguous=true;
+			}
+		}
+		//let's see if the first arg matches an option name (case insensitive)
+		if(!ambiguous && choice==-1U) {
+			std::string argname=string_util::makeLower(args[0]);
+			for(unsigned int i=0; i<options.size(); i++) {
+				if(options[i]!=NULL) {
+					std::string optname=string_util::makeLower(options[i]->name);
+					if(optname.compare(0,argname.size(),argname)==0) {
+						if(choice==-1U)
+							choice=i;
+						else
+							ambiguous=true;
+					}
+				}
+			}
+		}
+		//if we didn't find one already, try treating the arg as an index number
+		if(ambiguous || choice==-1U) {
+			char* endp=NULL;
+			choice=strtol(args[0].c_str(),&endp,10);
+			if(endp==NULL || endp==args[0].c_str()) {
+				if(config->main.use_VT100) {
+					sout->printf("\r\33[1A");
+					clearMenu();
+					doRewrite=false;
+				}
+				if(ambiguous)
+					serr->printf("ControlBase(\"%s\")::takeInput(\"%s\") was ambiguous\n",name.c_str(),args[0].c_str());
+				else
+					serr->printf("ControlBase(\"%s\")::takeInput(\"%s\") was not a valid index or option name.\n",name.c_str(),args[0].c_str());
+				refresh();
+				return this;
+			} else if(choice<options.size() && options[choice]!=NULL) {
+				ambiguous=false;
+			} else {
+				if(config->main.use_VT100) {
+					sout->printf("\r\33[1A");
+					clearMenu();
+					doRewrite=false;
+				}
+				if(ambiguous)
+					serr->printf("ControlBase(\"%s\")::takeInput(\"%s\") was ambiguous\n",name.c_str(),args[0].c_str());
+				else
+					serr->printf("ControlBase(\"%s\")::takeInput(\"%d\") is not a valid selection\n",name.c_str(),choice);
+				refresh();
+				return this;
+			}	
+		}
+		//see what we got...
+		if(args.size()>1)
+			return options[choice]->takeInput(str.substr(offsets[1]));
+		else {
+			hilights.clear();
+			hilights.push_back(choice);
+			return doSelect();
+		}
+	}
+	/*	std::string msg;
 	{unsigned int i=0; while(i<str.size() && isspace(str[i])) i++; msg=str.substr(i);}
 	if(isdigit(msg[0])) {
 		char* endp=NULL;
@@ -248,7 +329,7 @@ ControlBase* ControlBase::takeInput(const std::string& str) {
 		serr->printf("ControlBase::takeInput(\"%s\") was not understood.\nPlease enter the number of the index - string entry is not supported yet\n",str.c_str());
 		refresh();
 		return this;		
-	}
+		}*/
 }
 
 bool ControlBase::validInput(const std::string& str) {
@@ -329,9 +410,9 @@ float ControlBase::hilightsAvg() const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.6 $
- * $State: Exp $
- * $Date: 2003/06/12 18:06:10 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.8 $
+ * $State: Rel $
+ * $Date: 2003/08/06 22:50:41 $
  */
 
