@@ -23,6 +23,15 @@ void FreeMemReportControl::processEvent(const EventBase& e) {
 		ASSERT(false,"Unexpected timer event");
 }
 	
+void FreeMemReportControl::refresh() {
+	char tmp[256];
+	sprintf(tmp,"Free Mem: %d",freeMem());
+	options[1]->setName(tmp);
+	ControlBase::refresh();
+	report();
+}
+
+
 //! reports size of free memory - if this is below low_mem, also generates a warning
 void FreeMemReportControl::report() {
 	size_t freemem=freeMem();
@@ -42,10 +51,10 @@ size_t FreeMemReportControl::freeMem() {
 }
 
 void FreeMemReportControl::resetTimerFreq() {
-	if(report_freq==-1U)
+	if(report_freq<0)
 		erouter->removeTimer(this,0);
 	else
-		erouter->addTimer(this,0,report_freq*1000,true);
+		erouter->addTimer(this,0,report_freq,true);
 	erouter->addTimer(this,1,monitor_freq,true);
 }
 
@@ -54,9 +63,9 @@ void FreeMemReportControl::resetTimerFreq() {
  * @author ejt (object), alokl (core function)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.2 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:36 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.4 $
+ * $State: Rel $
+ * $Date: 2003/09/25 15:26:11 $
  */
 
