@@ -16,7 +16,7 @@ public:
 	FreeMemReportControl() : BehaviorBase(), ControlBase("Free Memory Report","Reports size of free memory, and monitors for low memory warning"), report_freq(-1U), low_mem(256), monitor_freq(1000), isWarning(false) {init();}
 	FreeMemReportControl(const std::string& n) : BehaviorBase(), ControlBase(n,"Reports size of free memory, and monitors for low memory warning"), report_freq(-1U), low_mem(256), monitor_freq(1000),isWarning(false) {init();}
 	FreeMemReportControl(const std::string& n, const std::string& d) : BehaviorBase(), ControlBase(n,d), report_freq(-1U), low_mem(256), monitor_freq(1000),isWarning(false) {init();}
-	virtual ~FreeMemReportControl() { SetAutoDelete(false); clearSlots(); } //!< destructor
+	virtual ~FreeMemReportControl() { SetAutoDelete(false); DoStop(); clearSlots(); } //!< destructor
 	//@}
 
 	virtual void DoStart() {
@@ -34,8 +34,8 @@ public:
 
 	virtual std::string getName() const { return (isActive()?"#":"-")+ControlBase::getName(); }
 
-	virtual void refresh() { ControlBase::refresh(); report(); }
-
+	virtual void refresh();
+	
 	//! reports size of free memory - if this is below low_mem, also generates a warning
 	void report();
 
@@ -49,12 +49,13 @@ protected:
 	//! builds the submenus
 	void init() {
 		pushSlot(new BehaviorActivatorControl(this));
-		pushSlot(new ValueEditControl<unsigned int>("Report Frequency","Controls how often to generate free memory reports (in seconds)","Please enter seconds to wait between reports (-1 to stop)",&report_freq));
+		pushSlot(new NullControl("Free Mem: unknown"));
+		pushSlot(new ValueEditControl<int>("Report Frequency","Controls how often to generate free memory reports (in milliseconds)","Please enter milliseconds to wait between reports (-1 to stop)",&report_freq));
 		pushSlot(new ValueEditControl<unsigned int>("Low Memory Threshold","Controls when to start warning about low memory (in KB)","Please enter the new low memory warning threshold (in KB)",&low_mem));
 		pushSlot(new ValueEditControl<unsigned int>("Monitor Frequency","Controls how often to check for low memory (in milliseconds)","Please enter milliseconds to wait between low memory checks (-1 to stop)",&monitor_freq));
 	}
 
-	unsigned int report_freq;  //!< how often to report memory size (in seconds - -1U turns off, 0 is as often as possible)
+	int report_freq;  //!< how often to report memory size (in milliseconds - negative turns off, 0 is as often as possible)
 	unsigned int low_mem;      //!< threshold to trigger low memory warning (in kilobytes)
 	unsigned int monitor_freq; //!< how often to check for low memory (in milliseconds - -1U turns off, 0 is as often as possible)
 	bool isWarning;            //!< true we already know we're below threshold
@@ -65,10 +66,10 @@ protected:
  * @author ejt (object), alokl (core function)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.3 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:36 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.6 $
+ * $State: Rel $
+ * $Date: 2003/09/26 03:28:38 $
  */
 
 #endif
