@@ -6,6 +6,7 @@
 #include "Motion/PostureMC.h"
 #include "Motion/MMAccessor.h"
 #include "Motion/EmergencyStopMC.h"
+#include "Events/EventRouter.h"
 #include <string>
 
 //! Upon activation, loads a position from a file name read from cin (stored in ms/data/motion...)
@@ -59,10 +60,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.9 $
- * $State: Exp $
- * $Date: 2003/06/10 00:53:48 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.10 $
+ * $State: Rel $
+ * $Date: 2003/07/26 01:48:03 $
  */
 
 #endif
