@@ -14,14 +14,16 @@ class SavePostureControl : public StringInputControl {
 	SavePostureControl(const std::string& n) : StringInputControl(n,"Saves current posture to filename read from user","Please enter name for posture file (in /ms/data/motion)...") {}
 
 	virtual ControlBase * takeInput(const std::string& msg) {
-		std::string filename;
-		if(msg[0]=='/')
-			filename=msg;
-		else
-			filename="/ms/data/motion/"+msg;
-		PostureEngine post;
-		post.takeSnapshot();
-		post.SaveFile(filename.c_str());
+		if(msg.size()>0) {
+			std::string filename;
+			if(msg[0]=='/')
+				filename=msg;
+			else
+				filename="/ms/data/motion/"+msg;
+			PostureEngine post;
+			post.takeSnapshot();
+			post.SaveFile(filename.c_str());
+		}
 		return StringInputControl::takeInput(msg);
 	}
 };
@@ -31,10 +33,10 @@ class SavePostureControl : public StringInputControl {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.6 $
- * $State: Exp $
- * $Date: 2003/06/12 18:06:10 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.7 $
+ * $State: Rel $
+ * $Date: 2003/07/28 05:54:32 $
  */
 
 #endif
