@@ -14,7 +14,7 @@ public:
 	//! Constructor
 	StringInputControl(const std::string& n, const std::string& desc, const std::string& prompt) : ControlBase(n,desc), lastInput(), userPrompt(prompt) {}
 
-	virtual ControlBase* activate(MotionManager::MC_ID disp_id, Socket* gui);
+	//	virtual ControlBase* activate(MotionManager::MC_ID disp_id, Socket* gui);
 	
 	virtual void refresh();
 	
@@ -41,10 +41,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.2 $
- * $State: Exp $
- * $Date: 2003/06/12 18:06:10 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.4 $
+ * $State: Rel $
+ * $Date: 2003/09/25 15:26:11 $
  */
 
 #endif
