@@ -12,6 +12,7 @@
 #include "Motion/LedMC.h"
 #include "Shared/ERS210Info.h"
 #include "Shared/ERS220Info.h"
+#include "Motion/MMAccessor.h"
 
 //! A background behavior which will monitor the power level and flip the ears when appropriate on a 210, or blink the headlight if a 220
 /*! Think of this as a simple example class.  For exercise, try using a MotionSequenceMC instead
@@ -101,7 +102,7 @@ public:
 protected:
 	//! adds a pose and a timer to get the ears flipping
 	void startWarning() {
-		cout << "LOW BATTERY" << endl;
+		serr->printf("LOW BATTERY\n");
 		pose_id=motman->addMotion(SharedObject<PostureMC>(),MotionManager::kEmergencyPriority+1);
 		pose=(PostureMC*)motman->peekMotion(pose_id);
 		SharedObject<LedMC> led;
@@ -112,7 +113,7 @@ protected:
 	}
 	//! removes pose, in case battery magically charges
 	void stopWarning() {
-		cout << "BATTERY GOOD" << endl;
+		serr->printf("BATTERY GOOD\n");
 		motman->removeMotion(pose_id);
 		motman->removeMotion(led_id);
 		led_id=pose_id=MotionManager::invalid_MC_ID;
@@ -151,10 +152,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.10 $
- * $State: Exp $
- * $Date: 2003/06/12 18:06:10 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.12 $
+ * $State: Rel $
+ * $Date: 2003/07/26 01:48:09 $
  */
 
 #endif
