@@ -5,6 +5,7 @@
 #include "Motion/HeadPointerMC.h"
 #include "Motion/WalkMC.h"
 #include "Vision/Vision.h"
+#include "Shared/WMclass.h"
 
 //! Converts degrees to radians
 inline double DtoR(double deg) { return (deg/180.0*M_PI); }
@@ -14,13 +15,9 @@ void ChaseBallBehavior::DoStart() {
 	headpointer_id = motman->addMotion(SharedObject<HeadPointerMC>());
 	walker_id = motman->addMotion(SharedObject<WalkMC>());
 	erouter->addListener(this,EventBase::visionEGID);
-  vision->enableEvents(VisionEventNS::RedBallSID);
-  vision->enableEvents(VisionEventNS::PinkBallSID);
 }
 
 void ChaseBallBehavior::DoStop() {
-  vision->disableEvents(VisionEventNS::RedBallSID);
-  vision->disableEvents(VisionEventNS::PinkBallSID);
 	erouter->forgetListener(this);
 	motman->removeMotion(headpointer_id);
 	motman->removeMotion(walker_id);
@@ -29,7 +26,10 @@ void ChaseBallBehavior::DoStop() {
 
 //this could be cleaned up event-wise (only use a timer when out of view)
 void ChaseBallBehavior::processEvent(const EventBase& event) {
-	static float horiz=0,vert=0;
+  WMreg(chase_ball_behavior);
+  WMvari_(float, horiz, 0, chase_ball_behavior);
+  WMvari_(float, vert, 0, chase_ball_behavior);
+
 	if(event.getGeneratorID()==EventBase::visionEGID && event.getTypeID()==EventBase::statusETID) {
 		horiz=static_cast<const VisionEvent*>(&event)->getCenterX();
 		vert=static_cast<const VisionEvent*>(&event)->getCenterY();
@@ -37,7 +37,7 @@ void ChaseBallBehavior::processEvent(const EventBase& event) {
 
 	WalkMC * walker = (WalkMC*)motman->checkoutMotion(walker_id);
 	if(state->outputs[HeadOffset+PanOffset]<-.05 || state->outputs[HeadOffset+PanOffset]>.05)
-		walker->setTargetVelocity(100,0,state->outputs[HeadOffset+PanOffset]*2);
+		walker->setTargetVelocity(100,0,state->outputs[HeadOffset+PanOffset]);
 	else
 		walker->setTargetVelocity(160,0,0);
 	motman->checkinMotion(walker_id);
@@ -64,10 +64,10 @@ void ChaseBallBehavior::processEvent(const EventBase& event) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.2 $
- * $State: Exp $
- * $Date: 2003/03/09 02:45:21 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.5 $
+ * $State: Rel $
+ * $Date: 2003/09/12 21:37:47 $
  */
 
 
