@@ -1,4 +1,3 @@
-#include "BehaviorBase.h"
 #include "Motion/MotionManager.h"
 #include "Motion/WalkMC.h"
 #include "Motion/MotionSequenceMC.h"
@@ -110,9 +109,9 @@ void DriveMeBehavior::processEvent(const EventBase& event)
  * @author tss (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.3 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:39 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.4 $
+ * $State: Rel $
+ * $Date: 2003/07/25 20:18:04 $
  */
 
