@@ -2,7 +2,7 @@
 #ifndef INCLUDED_DriveMeBehavior_h_
 #define INCLUDED_DriveMeBehavior_h_
 
-#include "BehaviorBase.h"
+#include "Behaviors/BehaviorBase.h"
 #include "Motion/MotionManager.h"
 #include "Motion/MotionSequenceMC.h"
 #include "Shared/SharedObject.h"
@@ -39,10 +39,10 @@ protected:
  * @author tss (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.4 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:39 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.5 $
+ * $State: Rel $
+ * $Date: 2003/07/25 20:18:05 $
  */
 
 #endif
