@@ -23,7 +23,8 @@ public:
 	//! prints out data on subscribed events
 	virtual void processEvent(const EventBase& event);
 			
-	virtual const char* getName() const { return (isActive()?"#EvtRptBehavior":"-EvtRptBehavior"); } //!< returns name of behavior
+	virtual std::string getName() const { return "EvtRptBehavior"; }
+	static std::string getClassDescription() { return "A simple behavior to test event reports"; }
 };
 
 /*! @file
