@@ -30,10 +30,6 @@ public:
 		BehaviorBase::DoStart();
 		walker_id = motman->addMotion(SharedObject<WalkMC>());
 		erouter->addListener(this,EventBase::visionEGID);
-		// in the near future, these two will be unnecessary.
-		// (vision will use erouter to check if it has listeners)
-		vision->enableEvents(VisionEventNS::RedBallSID);
-		vision->enableEvents(VisionEventNS::PinkBallSID);
 	}
 
 	//! removes motion commands and stops listening
@@ -65,10 +61,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.3 $
- * $State: Exp $
- * $Date: 2003/06/12 18:06:11 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.4 $
+ * $State: Rel $
+ * $Date: 2003/07/28 18:39:18 $
  */
 
 #endif
