@@ -12,13 +12,9 @@ void StareAtBallBehavior::DoStart() {
 	BehaviorBase::DoStart();
 	headpointer_id = motman->addMotion(SharedObject<HeadPointerMC>());
 	erouter->addListener(this,EventBase::visionEGID);
-  vision->enableEvents(VisionEventNS::RedBallSID);
-  vision->enableEvents(VisionEventNS::PinkBallSID);
 }
 
 void StareAtBallBehavior::DoStop() {
-  vision->disableEvents(VisionEventNS::RedBallSID);
-  vision->disableEvents(VisionEventNS::PinkBallSID);
 	erouter->forgetListener(this);
 	motman->removeMotion(headpointer_id);
 	BehaviorBase::DoStop();
