@@ -32,7 +32,7 @@ public:
 	std::string getName() const { return "ToggleHeadLightBehavior"; }
 
 protected:
-	MotionManager::MC_ID light_id;
+	MotionManager::MC_ID light_id; //!< id value of the PostureMC used to control the light
 };
 
 /*! @file
@@ -40,10 +40,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.1 $
- * $State: Exp $
- * $Date: 2003/06/28 18:03:57 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.2 $
+ * $State: Rel $
+ * $Date: 2003/09/02 20:58:49 $
  */
 
 #endif
