@@ -6,8 +6,8 @@
 
 #include "WorldModel2Behavior.h"
 
-#include "StateNode.h"
-#include "Transitions/TimeOutTrans.h"
+#include "Behaviors/StateNode.h"
+#include "Behaviors/Transitions/TimeOutTrans.h"
 #include "Motion/MotionManager.h"
 #include "Motion/WalkMC.h"
 #include "Motion/HeadPointerMC.h"
