@@ -5,6 +5,7 @@
 #include <vector>
 #include <iostream>
 #include <stdlib.h>
+#include <math.h>
 
 //!Makes decisions regarding an adversarial k-armed bandit
 /*! Uses algorithms described in:
@@ -112,8 +113,8 @@ class karmedbanditExp3_1 {
 	void restart() {
 		std::cout << "Exp3 restart, g=" << std::flush;
 		unsigned int k=exp3.getK();
-		gr=(k*log(k))/(M_E-1)*pow(4,r);
-		double gammap=sqrt(k*log(k)/(M_E-1)/gr);
+		gr=(k*log((double)k))/(M_E-1)*pow(4.0,(double)r);
+		double gammap=sqrt(k*log((double)k)/(M_E-1)/gr);
 		//		exp3.reset(); //not sure if we're supposed to do this
 		exp3.setGamma(gammap<1?gammap:1);
 		std::cout << (gammap<1?gammap:1) << std::endl;
@@ -130,11 +131,11 @@ class karmedbanditExp3_1 {
  * @brief Defines karmedbandit - implements an algorithm which makes decisions regarding an adversarial k-armed bandit
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.2 $
- * $State: Exp $
- * $Date: 2003/03/03 01:18:12 $
+ * $Author: neilh $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.3 $
+ * $State: Rel $
+ * $Date: 2003/09/18 22:40:27 $
  */
 
 #endif
