@@ -12,14 +12,14 @@
 class StateNode  : public BehaviorBase {
 public:
 	//!constructor
-	StateNode() : BehaviorBase(), parent(NULL), transitions(), issetup(false), retain(true), nodes(), name("?") {}
+	StateNode() : BehaviorBase(), parent(NULL), transitions(), issetup(false), retain(true), nodes(), name("?") {	std::cout << "!" << std::endl;}
 
 	//!constructor, pass a name to use, calls setName(n) 
-	StateNode(const char* n, StateNode* p=NULL) : BehaviorBase(), parent(p), transitions(), issetup(false), retain(true), nodes(), name(NULL) {
+	StateNode(const char* n, StateNode* p=NULL) : BehaviorBase(), parent(p), transitions(), issetup(false), retain(true), nodes(), name("") {
 		setName(n);
 	}
 
-	//!destructor, frees memory used by its outgoing transitions (be careful of incoming ones - they're still around!), and calls RemoveReference() on subnodes
+	//!destructor, removes references to its outgoing transitions (be careful of incoming ones - they're still around!), and calls RemoveReference() on subnodes
 	virtual ~StateNode();
 
 	//!Adds the specified StateTransition to the transition table
@@ -28,7 +28,7 @@ public:
 	//!Returns the std::vector of transitions so you can modify them yourself if need be
 	std::vector<Transition*>& getTransitions() { return transitions; }
 
-	//!Adds a StateNode to #nodes so it can be automatically deleted later, returns what it's passed (for convenience), calls AddReference() on @a node
+	//!Adds a StateNode to #nodes so it can be automatically dereferenced later, returns what it's passed (for convenience), calls AddReference() on @a node
 	virtual StateNode* addNode(StateNode* node) { nodes.push_back(node); node->AddReference(); return node; }
 
 	//!Returns the std::vector of nodes so you can modify them yourself if need be
@@ -38,14 +38,17 @@ public:
 	void setRetain(bool f) { retain=f; }
 
 	//!Transitions should call this when you are entering the state, so it can enable its transitions
-	void DoStart();
+	virtual void DoStart();
 
-	//!This is called by DoStart() when you should setup the network
+	//!This is called by DoStart() when you should setup the network of subnodes
 	virtual void setup() {issetup=true;}
 
 	//!Transitions should call this when you are leaving the state, so it can disable its transitions
-	void DoStop();
+	virtual void DoStop();
 	
+	//!This is called by DoStop() when you should destruct subnodes
+	virtual void teardown() { std::cout << "Teardown!!!!!!!!" << std::endl;issetup=false;}
+
 	//!set name to @a n.  Makes a copy of @a n, so you can throw it away later.
 	void setName(const std::string& n);
 
@@ -55,16 +58,13 @@ public:
 	//!returns name again (you should override this for top-level nodes to give users better descriptions)
 	virtual std::string getDescription() const { return name; }
 
-	//!Doesn't do anything, supplied here so you don't have to (since events will probably be going to Transition's, not here)
-	virtual void processEvent(const EventBase&) {}
-
+protected:
 	//!called by a subnode when it is being DoStart()'ed
-	void transitionTo(StateNode* n);
+	virtual void transitionTo(StateNode* n);
 
 	//!called by a subnode when it is being DoStop()'ed
-	void transitionFrom(StateNode* n);
+	virtual void transitionFrom(StateNode* n);
 
-protected:
 	//Node Stuff:
 	//! pointer to the machine that contains this node
 	StateNode* parent;
@@ -74,9 +74,9 @@ protected:
 	//Machine Stuff:
 	//! this is set to true if the network has been setup but not destroyed (i.e. don't need to call setupSubNodes again)
 	bool issetup;
-	//! this is set to true if the network should be retained between activations.  Otherwise it's deleted upon DoStop(). (or at least RemoveReference() is called on subnodes)
+	//! this is set to true if the network should be retained between activations.  Otherwise it's dereferenced upon DoStop(). (or at least RemoveReference() is called on subnodes)
 	bool retain;
-	//! vector of StateNodes, just so they can be deleted again on DoStop() (unless retained) or ~StateNode()
+	//! vector of StateNodes, just so they can be dereferenced again on DoStop() (unless retained) or ~StateNode()
 	std::vector<StateNode*> nodes;
 
 	//Behavior Stuff:
@@ -93,10 +93,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.2 $
- * $State: Exp $
- * $Date: 2003/06/05 17:03:09 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.7 $
+ * $State: Rel $
+ * $Date: 2003/09/25 15:23:56 $
  */
 
 #endif
