@@ -22,7 +22,7 @@
  *  Passing NULL as the value to monitor will cause a transition on the first event received
  */
 template<class T>
-class CompareTrans : public Transition, public EventListener {
+class CompareTrans : public Transition {
 public:
 	//! use these values to sepecify what kind of comparison should be made to test for activation
 	enum Test_t {
@@ -36,14 +36,14 @@ public:
 	
 	//! constructor, see class notes for information
   CompareTrans(StateNode* source, StateNode* destination, const T* monitor, Test_t test, const T& value, const EventBase& poll)
-		: Transition(source,destination), EventListener(), mon(monitor), tst(test), val(value), poller(poll)
+		: Transition(source,destination), mon(monitor), tst(test), val(value), poller(poll)
 	{ }
 	
 	//!starts listening
-	virtual void enable() { erouter->addListener(this,poller); }
+	virtual void DoStart() { Transition::DoStart(); erouter->addListener(this,poller); }
 
 	//!stops listening
-	virtual void disable() { erouter->forgetListener(this); }
+	virtual void DoStop() { erouter->forgetListener(this); Transition::DoStop(); }
 
 	//!don't care about the event, just a pulse to check the values
 	virtual void processEvent(const EventBase&) {
@@ -69,6 +69,8 @@ public:
 		}
 	}
 
+	virtual std::string getName() const { return "CompareTrans"; }
+
 protected:
 	const T* mon; //!< address of value to monitor
 	Test_t tst; //!< test to make
@@ -85,10 +87,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.2 $
- * $State: Exp $
- * $Date: 2003/03/09 02:45:22 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.4 $
+ * $State: Rel $
+ * $Date: 2003/09/25 15:26:57 $
  */
 
 #endif
