@@ -15,7 +15,8 @@ const char* const EventBase::EventGeneratorNames[numEGIDs] = {
 	"Locomotion",
 	"TextMsg",
 	"EStop",
-	"MotionManager"
+	"MotionManager",
+	"WMVariable"
 };
 
 
@@ -169,9 +170,9 @@ EventBase::genName() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.10 $
- * $State: Exp $
- * $Date: 2003/04/25 18:22:39 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.12 $
+ * $State: Rel $
+ * $Date: 2003/10/07 01:00:28 $
  */
 
