@@ -49,6 +49,7 @@ class EventBase : public LoadSave {
     textmsgEGID,      //!< Sends events when a text msg is received on console
 		estopEGID,        //!< Sends an event when the estop is turned on or off
 		motmanEGID,       //!< Sends events when a MotionCommand is added or removed
+		wmVarEGID,        //!< Sends an event when a watched memory is changed; source id is pointer to WMEntry
 		numEGIDs          //!< the number of generators available
 	};
 
@@ -140,10 +141,10 @@ class EventBase : public LoadSave {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.12 $
- * $State: Exp $
- * $Date: 2003/04/09 04:48:15 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.14 $
+ * $State: Rel $
+ * $Date: 2003/10/07 01:00:28 $
  */
 
 #endif
