@@ -150,12 +150,14 @@ void EventRouter::doSendEvent(const EventBase& e) {
 	std::vector<EventTrapper*> t;
 	trappers.getMapping(e,t);
 	for(std::vector<EventTrapper*>::iterator it=t.begin(); it!=t.end(); it++)
-		if((*it)->trapEvent(e))
-			return;
+		if(trappers.verifyMapping(*it,e))
+			if((*it)->trapEvent(e))
+				return;
 	std::vector<EventListener*> l;
 	listeners.getMapping(e,l);
 	for(std::vector<EventListener*>::iterator it=l.begin(); it!=l.end(); it++)
-		(*it)->processEvent(e);
+		if(listeners.verifyMapping(*it,e))
+			(*it)->processEvent(e);
 	//	cout << "done." << flush;
 }
 
@@ -317,15 +319,39 @@ void EventRouter::EventMapper::getMapping(const EventBase& e, std::vector<T*>& l
 		ls.push_back(static_cast<T*>(*elit));
 }
 
+bool EventRouter::EventMapper::verifyMapping(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+	// first get all the filtered subscribers (tricky!)
+	std::vector<void*>* elv=NULL;
+	SIDtoListenerVectorMap_t* sidtovm=filteredevents[egid][etid];
+	if(sidtovm!=NULL) { // if there's a map (at least one EL is filtering on this EGID and ETID)
+		SIDtoListenerVectorMap_t::iterator mapit=sidtovm->find(sid); // find listening for this source id
+		if(mapit!=sidtovm->end()) { // if there's at least one is filtering on this sourceID as well
+			elv=&(*mapit).second; // now go through them all
+			for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+				if(*elit==listener)
+					return true;
+		}
+	}
+	// now get the 'all events' subscribers
+	elv=&allevents[egid];
+	for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+		if(*elit==listener)
+			return true;
+
+	// if we haven't found it, doesn't exist:
+	return false;
+}
+
+
 /*! @file
  * @brief Implements EventRouter class, for distribution and trapping of events to listeners
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.8 $
- * $State: Exp $
- * $Date: 2003/06/09 08:05:13 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.10 $
+ * $State: Rel $
+ * $Date: 2003/10/03 03:41:01 $
  */
 
 
