@@ -111,8 +111,14 @@ class EventRouter : public EventListener {
 	//@}
 
  protected:
-	void doSendBuffer(); //!< does the work of clearing the buffer
-	void doSendEvent(const EventBase& e); //!< does the work of sending an event
+	void doSendBuffer(); //!< does the work of clearing the buffer (calls doSendEvent() )
+	
+	//! does the work of sending an event
+	/*! Be aware this is an O(n^2) where n is the number of listeners for a particular event.
+	 *  This is because after each call to processEvent, the list of listeners could have changed
+	 *  so each listener much be verified before it is sent an event.  New listeners won't get the
+	 *  current event, but neither should listeners which have just be removed */
+	void doSendEvent(const EventBase& e); 
 
 	//! Contains all the information needed to maintain a timer by the EventRouter
 	struct TimerEntry {
@@ -200,9 +206,9 @@ class EventRouter : public EventListener {
 
 		//@{
 		//! so stuff can tell if it even needs to bother generating an event...
-		/* ... if a tree falls in a forest, and there's no one around to see it, does it make a sound?
-			 ... if Vision sees a ball in an image, and there's no listeners, does it make an event? ;) */
-		/*! @return true if it has any listeners, false otherwise */
+		/*! ... if a tree falls in a forest, and there's no one around to see it, does it make a sound?\n
+			  ... if Vision sees a ball in an image, and there's no listeners, does it make an event? ;) \n
+			  @return true if it has any listeners, false otherwise */
 		bool hasMapping(EventBase::EventGeneratorID_t egid);
 		bool hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid);
 		bool hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid);
@@ -216,6 +222,14 @@ class EventRouter : public EventListener {
 		template<class T>
 		void getMapping(const EventBase& e, std::vector<T*>& listeners);
 
+		//! Used to make sure that the specified listener exists for the given event
+		/*! This is needed because after we call processEvent on a lister, we can't assume
+		 *  that no other listeners have been modified - one listener could cause another
+		 *  to turn off.  If that has happened, we shouldn't send the event, even if it
+		 *  was in the queue originally. */
+		bool verifyMapping(void * listener, const EventBase& e) { return verifyMapping(listener,e.getGeneratorID(),e.getSourceID(),e.getTypeID()); }
+		bool verifyMapping(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid);
+
 	protected:
 		//! a mapping from source IDs (unsigned ints), each to a vector of pointers to listeners
 		/*! main use in filteredevents @see filteredevents */
@@ -244,10 +258,10 @@ extern EventRouter * erouter;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.10 $
- * $State: Exp $
- * $Date: 2003/04/25 18:22:39 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.12 $
+ * $State: Rel $
+ * $Date: 2003/10/03 03:41:01 $
  */
 
 #endif
