@@ -8,13 +8,12 @@
 namespace VisionEventNS {
 	//! contains source IDs for the objects we can recognize
   enum VisionSourceID_t {
+    PinkBallSID=0,//!< the plastic pink ball Aibos ship with
     RedBallSID=0, //!< a red bean bag ball
-    PinkBallSID,  //!< the plastic pink ball Aibos ship with
     HandSID,      //!< Optimized for Ethan's hand, a pasty white thing.
     ThumbsupSID,  //!< Recognizes when Ethan is giving a thumbs up.
     ThingSID,     //!< Other stuff
-    MarkersSID    //!< never actually generated: data directly
-                  //!  reported to WorldModel
+    MarkersSID    //!< never actually generated: data directly reported to WorldModel
   };
 }
 
@@ -98,10 +97,10 @@ class VisionEvent : public EventBase {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.7 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:40 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.9 $
+ * $State: Rel $
+ * $Date: 2003/09/12 21:38:20 $
  */
 
 #endif
