@@ -11,6 +11,7 @@
 #include "SoundPlay/SoundManager.h"
 #include "Vision/Vision.h"
 #include "Events/TextMsgEvent.h"
+#include "Shared/WMclass.h"
 
 #include "Shared/ERS210Info.h"
 #include "Shared/ERS220Info.h"
@@ -79,6 +80,8 @@ MMCombo::DoInit(const OSystemEvent&)
     wireless = new Wireless();
     sout=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*6);
     serr=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*2);
+    wireless->setDaemon(sout);
+    wireless->setDaemon(serr);
 		serr->setFlushType(SocketNS::FLUSH_BLOCKING);
     sout->setTextForward();
     serr->setForward(sout);
@@ -95,7 +98,11 @@ MMCombo::DoInit(const OSystemEvent&)
 
     //Setup vision
     vision=new Vision();
-
+		// someday these will go away:
+		vision->enableEvents(VisionEventNS::PinkBallSID);
+		vision->enableEvents(VisionEventNS::RedBallSID);
+		vision->enableEvents(VisionEventNS::MarkersSID);
+	
 	}
 	if(strcmp(objectName,"MotoObj")==0) {
 		ProcessID::setID(ProcessID::MotionProcess);
@@ -416,22 +423,25 @@ MMCombo::GotImage(const ONotifyEvent& event){
 	PROFSECTION("GotImage()",state->mainProfile);
 	etrans.translateEvents();
 
-  const OFbkImageVectorData *fbkImageVectorData=reinterpret_cast<const OFbkImageVectorData*>(event.Data(0));
-  OFbkImageInfo* info = const_cast<OFbkImageVectorData*>(fbkImageVectorData)->GetInfo(0);
-  const byte* dat = const_cast<OFbkImageVectorData*>(fbkImageVectorData)->GetData(0);
-  const OFbkImage yimage(info, const_cast<byte*>(dat), ofbkimageBAND_Y);
-  const OFbkImage uimage(info, const_cast<byte*>(dat), ofbkimageBAND_Cr);
-  const OFbkImage vimage(info, const_cast<byte*>(dat), ofbkimageBAND_Cb);
-            
-  const byte* bytes_y = yimage.Pointer();
-  const byte* bytes_u = uimage.Pointer();
-  const byte* bytes_v = vimage.Pointer();
+  if (vision!=NULL) {
+    const OFbkImageVectorData *fbkImageVectorData=reinterpret_cast<const OFbkImageVectorData*>(event.Data(0));
+    OFbkImageInfo* info = const_cast<OFbkImageVectorData*>(fbkImageVectorData)->GetInfo(vision->imageLayer);
+    const byte* dat = const_cast<OFbkImageVectorData*>(fbkImageVectorData)->GetData(vision->imageLayer);
+    const OFbkImage yimage(info, const_cast<byte*>(dat), ofbkimageBAND_Y);
+    const OFbkImage uimage(info, const_cast<byte*>(dat), ofbkimageBAND_Cr);
+    const OFbkImage vimage(info, const_cast<byte*>(dat), ofbkimageBAND_Cb);
 
-  int width  = yimage.Width();
-  int height = yimage.Height();
+    const byte* bytes_y = yimage.Pointer();
+    const byte* bytes_u = uimage.Pointer();
+    const byte* bytes_v = vimage.Pointer();
 
-  vision->processFrame(bytes_y, bytes_u, bytes_v, width, height);
- 
+    int width  = yimage.Width();
+    int height = yimage.Height();
+
+    WMvari(int, frame_counter, 0);
+    ++frame_counter;
+    vision->processFrame(bytes_y, bytes_u, bytes_v, width, height, yimage.Skip());
+  }
   erouter->processTimers();
   
   observer[obsImage]->AssertReady();
@@ -628,10 +638,10 @@ MMCombo::RPOPENR_send(char *buf, int bufsize) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.36 $
- * $State: Exp $
- * $Date: 2003/06/12 18:06:11 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.40 $
+ * $State: Rel $
+ * $Date: 2003/10/10 05:38:21 $
  */
 
 
