@@ -3,15 +3,16 @@
 #include "Shared/WorldState.h"
 #include "MotionManager.h"
 #include <math.h>
-
-const OutputCmd HeadPointerMC::unused;
+#include "Shared/Config.h"
 
 HeadPointerMC::HeadPointerMC() :
 	MotionCommand(), dirty(true), active(true) {
 	setWeight(1);
+	defaultMaxSpeed();
 	for(unsigned int i=0; i<NumHeadJoints; i++) {
 		headModes[i]=BodyRelative;
 		headValues[i]=0;
+		headJoints[i].value=state->outputs[HeadOffset+i];
 	}
 }
 
@@ -28,6 +29,12 @@ void HeadPointerMC::setWeight(double w) {
 	dirty=true;
 }
 
+void HeadPointerMC::defaultMaxSpeed() {
+	maxSpeed[TiltOffset]=config->motion.max_head_tilt_speed*FrameTime/1000;
+	maxSpeed[PanOffset]=config->motion.max_head_pan_speed*FrameTime/1000;
+	maxSpeed[RollOffset]=config->motion.max_head_roll_speed*FrameTime/1000;
+}
+
 void HeadPointerMC::setMode(CoordFrame_t m, bool conv) {
 	for(unsigned int x=0; x<NumHeadJoints; x++)
 		setJointMode((RobotInfo::TPROffset_t)x,m,conv);
@@ -45,13 +52,35 @@ int HeadPointerMC::updateOutputs() {
 	if(tmp) {
 		dirty=false;
 		for(unsigned int i=0; i<NumHeadJoints; i++) {
+			float value;
 			if(headModes[i]!=BodyRelative) {
-				headJoints[i].value=convToBodyRelative((RobotInfo::TPROffset_t)i,headValues[i],headModes[i]);
+				value=convToBodyRelative((RobotInfo::TPROffset_t)i,headValues[i],headModes[i]);
 				dirty=true;
 			} else
-				headJoints[i].value=headValues[i];
-			for(unsigned int f=0; f<NumFrames; f++)
+				value=headValues[i];
+			if(maxSpeed[i]<=0)
+				headJoints[i].value=value;
+			if(value==headJoints[i].value) {
 				motman->setOutput(this,i+HeadOffset,headJoints[i]);
+			} else { // we're trying to exceeded maxSpeed
+				unsigned int f=0;
+				while(value>headJoints[i].value+maxSpeed[i] && f<NumFrames) {
+					headJoints[i].value+=maxSpeed[i];
+					motman->setOutput(this,i+HeadOffset,headJoints[i],f);
+					f++;
+				}
+				while(value<headJoints[i].value-maxSpeed[i] && f<NumFrames) {
+					headJoints[i].value-=maxSpeed[i];
+					motman->setOutput(this,i+HeadOffset,headJoints[i],f);
+					f++;
+				}
+				if(f<NumFrames) { //we reached target value, fill in rest of frames
+					headJoints[i].value=value;
+					for(;f<NumFrames;f++)
+						motman->setOutput(this,i+HeadOffset,headJoints[i],f);
+				} else // we didn't reach target value, still dirty
+					dirty=true;
+			}
 		}
 	}
 	return tmp;
@@ -62,11 +91,11 @@ const OutputCmd& HeadPointerMC::getOutputCmd(unsigned int i) {
 	if(i<NumHeadJoints && getActive())
 		return headJoints[i];
 	else
-		return unused;
+		return OutputCmd::unused;
 }
 
 /*! @todo this is perhaps a bit amateurish - could be more accurate */
-double HeadPointerMC::convToBodyRelative(RobotInfo::TPROffset_t i, double v, CoordFrame_t mode) const {
+double HeadPointerMC::convToBodyRelative(TPROffset_t i, double v, CoordFrame_t mode) const {
 	switch(mode) {
 	default:
 		ASSERT(false,"Passed bad mode "<<mode);
@@ -92,7 +121,7 @@ double HeadPointerMC::convToBodyRelative(RobotInfo::TPROffset_t i, double v, Coo
 }
 
 /*! @todo this is perhaps a bit amateurish - could be more accurate */
-double HeadPointerMC::convFromBodyRelative(RobotInfo::TPROffset_t i, double v, CoordFrame_t mode) const {
+double HeadPointerMC::convFromBodyRelative(TPROffset_t i, double v, CoordFrame_t mode) const {
 	switch(mode) {
 	default:
 		ASSERT(false,"Passed bad mode "<<mode);
@@ -123,10 +152,10 @@ double HeadPointerMC::convFromBodyRelative(RobotInfo::TPROffset_t i, double v, C
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.6 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:40 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.8 $
+ * $State: Rel $
+ * $Date: 2003/09/07 22:14:01 $
  */
 
 
