@@ -59,25 +59,34 @@ class MMAccessor {
 			mcptr=(MC_t*)motman->peekMotion(id);
 	}
 
-	//! copy constructor - will reference the same mc_id - checkin/checkouts are NOT independent between this and @a a - they will be linked
-	MMAccessor(const MMAccessor& a) : mc_id(a.mc_id), mcptr(a.mcptr) {}
+	//! constructor, allows objects to provide uniform access to MotionCommands, regardless of whether they are currently in the MotionManager
+	MMAccessor(MotionCommand * ptr) : mc_id(invalid_MC_ID), mcptr(ptr) {}
+
+	//! copy constructor - will reference the same mc_id - checkin/checkouts are independent between this and @a a - motman does counting of checkin/checkouts
+	MMAccessor(const MMAccessor& a) : mc_id(a.mc_id), mcptr(a.mcptr) {
+		if(motman->isOwner(mc_id))
+			checkout();
+	}
 
 	//! destructor, checks in if needed
 	~MMAccessor() {
-		while(motman->checkoutLevel(mc_id)>0)
-			checkin();
+		checkin();
 	}
 
 	//! allows assignment of MMAccessor's, similar to the copy constructor - the two MMAccessor's will control the same MotionCommand
 	MMAccessor<MC_t> operator=(const MMAccessor<MC_t>& a) {
 		mc_id=a.mc_id;
 		mcptr=a.mcptr;
+		if(motman->isOwner(mc_id))
+			checkout();
 		return *this;
 	}
 	
 	//! So you can check out if not done by default (or you checked in already)
 	inline MC_t* checkout() {
-		return mcptr=dynamic_cast<MC_t*>(motman->checkoutMotion(mc_id)); //!< @test can this be a dynamic_cast?
+		if(mc_id!=MotionManager::invalid_MC_ID)
+			mcptr=dynamic_cast<MC_t*>(motman->checkoutMotion(mc_id)); 
+		return mcptr;
 	}
 
 	//! Returns the motion command's address so you can call functions
@@ -86,7 +95,10 @@ class MMAccessor {
 	//! Checks in the motion
 	/*! Don't forget, you can also just limit the scope using extra { }'s */
 	inline void checkin() {
-		motman->checkinMotion(mc_id);
+		if(motman->isOwner(mc_id)) {
+			motman->checkinMotion(mc_id);
+			mcptr=NULL; // fail fast if we use it after checkin
+		}
 	}
 
 	//! Checks in the motion, passing through the value it is passed.
@@ -116,7 +128,6 @@ class MMAccessor {
 	 *  @endcode*/
 	template<class Ret_t> Ret_t checkin(Ret_t ret) {
 		checkin();
-		mcptr=NULL;
 		return ret;
 	}
 
@@ -137,10 +148,10 @@ class MMAccessor {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.7 $
- * $State: Exp $
- * $Date: 2003/03/09 02:45:23 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.8 $
+ * $State: Rel $
+ * $Date: 2003/09/12 21:38:46 $
  */
 
 #endif
