@@ -101,7 +101,7 @@ public:
 	virtual void DoStart() { started=true; }
 
 	//! called after this is removed from MotionManager
-	virtual void DoStop() { started=false; }
+	virtual void DoStop() { started=false; clearID(); }
 
 	//! returns true if the MotionCommand is currently running (although it may be overridden by a higher priority MotionCommand)
 	virtual bool isActive() const { return started; }
@@ -166,10 +166,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.15 $
- * $State: Exp $
- * $Date: 2003/04/09 03:33:56 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.16 $
+ * $State: Rel $
+ * $Date: 2003/07/28 05:55:16 $
  */
 
 #endif
