@@ -9,7 +9,7 @@
 #include <list>
 
 MotionManager * motman=NULL;
-unsigned int MotionManager::_MMaccID=-1U;
+int MotionManager::_MMaccID=-1U;
 
 const float MotionManager::kIgnoredPriority    =-1;
 const float MotionManager::kBackgroundPriority = 0;
@@ -423,11 +423,15 @@ MotionManager::addMotion(const SharedObjectBase& sm) {
 	}
 	cmdlist[mc_id].baseaddrs[_MMaccID]=mc;
 	cmdlist[mc_id].rcr[_MMaccID]=sm.getRegion();
+	//cout << "addMotion(): sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
+	cmdlist[mc_id].rcr[_MMaccID]->AddReference();
+	//cout << "addMotion()NOW: sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
 	cmdlist[mc_id].lastAccessor=_MMaccID;
 	cmdlist[mc_id].priority=kStdPriority;
 	mc->setAdd(mc_id);
 	OStatus err;
 	ASSERT((err=subjs[_MMaccID]->SetData(sm.getRegion()))==oSUCCESS,"*** ERROR MotionManager: SetData returned " << err);
+	//cout << "addMotion()afterSetData: sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
 	ASSERT((err=subjs[_MMaccID]->NotifyObservers())==oSUCCESS,"*** ERROR MotionManager: NotifyObservers returned " << err);
 	//	cout << "addMotion-done" << endl;
 	return func_end(mc_id);
@@ -476,7 +480,9 @@ MotionManager::receivedMsg(const ONotifyEvent& event) {
 		MC_ID mc_id=mminfo->mc_id;
 		switch(mminfo->type) {
 		case MotionManagerMsg::addMotion: {
+			//cout << "receiveMotion(): rcr->NumberOfReference()==" << rcr->NumberOfReference() << endl;
 			rcr->AddReference();
+			//cout << "receiveMotion()NOW: rcr->NumberOfReference()==" << rcr->NumberOfReference() << endl;
 			cmdlist[mc_id].rcr[_MMaccID]=rcr;
 			//should be able to do a nice dynamic cast instead of a static one
 			// but it gives NULL for some reason - i blame having to do the fork trick
@@ -485,7 +491,9 @@ MotionManager::receivedMsg(const ONotifyEvent& event) {
 			cmdlist[mc_id].baseaddrs[_MMaccID]->DoStart();
 		} break;
 		case MotionManagerMsg::deleteMotion: {
+			//cout << "deleteMotion(): cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference() << endl;
 			cmdlist[mc_id].rcr[_MMaccID]->RemoveReference();
+			//cout << "deleteMotion()NOW: cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference() << endl;
 		} break;
 		default:
 			printf("*** WARNING *** unknown MotionManager msg type received\n");
@@ -530,10 +538,10 @@ MotionManager::checkoutMotion(MC_ID mcid,bool block) {
 
 void
 MotionManager::checkinMotion(MC_ID mcid) {
-	cmdlist[mcid].lock.release();
+	if(mcid!=invalid_MC_ID)
+		cmdlist[mcid].lock.release();
 }
 
-//! @test do i do this right, or does it leak memory?
 void
 MotionManager::removeMotion(MC_ID mcid) {
 	if(mcid==invalid_MC_ID)
@@ -547,7 +555,9 @@ MotionManager::removeMotion(MC_ID mcid) {
 	dmsg.setDelete(mcid);
 	subjs[_MMaccID]->SetData(&dmsg,sizeof(dmsg));
 	subjs[_MMaccID]->NotifyObservers();
+	//cout << "removeMotion(): cmdlist[mcid].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mcid].rcr[_MMaccID]->NumberOfReference() << endl;
 	cmdlist[mcid].rcr[_MMaccID]->RemoveReference();
+	//cout << "removeMotion()NOW: cmdlist[mcid].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mcid].rcr[_MMaccID]->NumberOfReference() << endl;
 #endif //PLATFORM_APERIOS
 	push_free(mcid);
 	checkinMotion(mcid);
@@ -647,10 +657,10 @@ MotionManager::OutputState::OutputState(unsigned int /*out*/, float pri, MC_ID m
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.22 $
- * $State: Exp $
- * $Date: 2003/06/12 04:16:43 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.25 $
+ * $State: Rel $
+ * $Date: 2003/10/07 01:00:40 $
  */
 
 
