@@ -63,7 +63,7 @@ public:
 	static const unsigned int MAX_MOTIONS=64;   //!< This is the maximum number of Motions which can be managed, can probably be increased reasonably without trouble
 
 	typedef MotionManagerMsg::MC_ID MC_ID;      //!< use this type when referring to the ID numbers that MotionManager hands out
-	static const MC_ID invalid_MC_ID=(MC_ID)-1; //!< for errors and undefined stuff
+	static const MC_ID invalid_MC_ID=MotionManagerMsg::invalid_MC_ID; //!< for errors and undefined stuff
 
 	MotionManager();                            //!< Constructor, sets all the outputs to 0
 
@@ -95,8 +95,9 @@ public:
 	//!@name MotionCommand "Risky"
 	MotionCommand * checkoutMotion(MC_ID mcid,bool block=true); //!< locks the command and possibly performs RTTI conversion; supports recursive calls
 	void checkinMotion(MC_ID mcid); //!< marks a MotionCommand as unused
-	MotionCommand * peekMotion(MC_ID mcid) { return cmdlist[mcid].baseaddrs[_MMaccID]; } //!< allows access to a MotionCommand without checking it out @warning @b never call a function based on this, only access member fields through it
-	unsigned int checkoutLevel(MC_ID mcid) { return cmdlist[mcid].lock.get_lock_level(); } //!< returns the number of times @a mcid has been checked out minus the times it's been checked in
+	MotionCommand * peekMotion(MC_ID mcid) { return mcid==invalid_MC_ID?NULL:cmdlist[mcid].baseaddrs[_MMaccID]; } //!< allows access to a MotionCommand without checking it out @warning @b never call a function based on this, only access member fields through it
+	unsigned int checkoutLevel(MC_ID mcid) { return mcid==invalid_MC_ID?0:cmdlist[mcid].lock.get_lock_level(); } //!< returns the number of times @a mcid has been checked out minus the times it's been checked in
+	bool isOwner(MC_ID mcid) { return mcid==invalid_MC_ID?false:(cmdlist[mcid].lock.owner()==_MMaccID); }
 	//@}
 
 	//!@name MotionCommand Unsafe
@@ -217,7 +218,7 @@ protected:
 	OSubject* subjs[MAX_ACCESS];           //!<The OSubject for each process (accessor) on which it should be broadcast when a command is added
 #endif
 
-	static unsigned int _MMaccID;          //!<Stores the accessor for the current process
+	static int _MMaccID;          //!<Stores the accessor for the current process
 
 private:
 	MotionManager(const MotionManager&); //!< this shouldn't be called...
@@ -232,10 +233,10 @@ extern MotionManager * motman;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.13 $
- * $State: Exp $
- * $Date: 2003/04/25 18:22:40 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.15 $
+ * $State: Rel $
+ * $Date: 2003/09/12 21:38:47 $
  */
 
 #endif
