@@ -7,8 +7,11 @@ struct MotionManagerMsg {
 	//! the type to use when referring to MotionCommand ID's
 	typedef unsigned short MC_ID;
 
+	//! for errors and undefined stuff
+	static const MC_ID invalid_MC_ID=static_cast<MC_ID>(-1); 
+
 	//! constructor
-	MotionManagerMsg() : type(unknown), mc_id(static_cast<MC_ID>(-1)) {}
+	MotionManagerMsg() : type(unknown), mc_id(invalid_MC_ID) {}
 
 	//! virtual destructor
 	/*! doesn't do anything, but don't remove it, otherwise this would no longer be a virtual base class */
@@ -17,6 +20,10 @@ struct MotionManagerMsg {
 	//! Accessor for the id number, set by MotionManager::addMotion()
 	MC_ID getID() const { return mc_id; }
 
+protected:
+	//! resets the #mc_id to #invalid_MC_ID
+	void clearID() { mc_id=invalid_MC_ID; }
+
 private:
 	friend class MotionManager;
 
@@ -45,10 +52,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.2 $
- * $State: Exp $
- * $Date: 2003/03/09 02:45:23 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.4 $
+ * $State: Rel $
+ * $Date: 2003/09/02 20:58:49 $
  */
 
 #endif // INCLUDED_MotionManagerMsg_h
