@@ -19,7 +19,7 @@ public:
 		pid[2]=a.pid[2]*w+b.pid[2]*(1-w);
 		weight=a.weight*w+b.weight*(1-w); 
 	} 
-	inline void unset() { weight=0; } //!< sets value and weight to 0 (same as assigning ::unusedJoint)
+	inline void unset() { weight=0; } //!< sets value and weight to 0
 
 	float pid[3]; //!< pid value of the output
 	float weight; //!< weight to be used in averaging, 0 to "fall through"
@@ -37,10 +37,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.3 $
- * $State: Exp $
- * $Date: 2003/04/09 07:01:30 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.4 $
+ * $State: Rel $
+ * $Date: 2003/09/07 22:14:01 $
  */
 
 #endif
