@@ -42,6 +42,7 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <fstream>
+#include <cmath>
 
 //REGIMP(WalkMC);
 
@@ -50,6 +51,8 @@
 const float WalkMC::MAX_DX   = 180;//225; // mm/sec
 const float WalkMC::MAX_DY   = 140;//170; // mm/sec
 const float WalkMC::MAX_DA   = 1.8;//2.1; // rad/sec
+// tss "SmoothWalk" modification follows
+// const vector3d WalkMC::max_accel_xya(MAX_DX*2,MAX_DY*2,MAX_DA*2);
 const vector3d WalkMC::max_accel_xya(MAX_DX*2,MAX_DY*2,MAX_DA*2);
 
 unsigned int checksum(const char *data,int num); //!< computes a file checksum
@@ -57,10 +60,16 @@ template <class data> int read_file(data *arr,int num,const char *filename); //!
 template <class data> int save_file(data *arr,int num,const char *filename); //!< saves the current walk parameters to a file
 
 WalkMC::WalkMC(const char* pfile/*=NULL*/)
+// tss "SmoothWalk" modification follows
+//	: MotionCommand(), isPaused(false), wp(), body_loc(), body_angle(),
+//		pos_delta(0,0,0), angle_delta(0), travelTime(get_time()),
+//		time(get_time()), TimeStep(FrameTime), vel_xya(0,0,0),
+//		target_vel_xya(0,0,0)
 	: MotionCommand(), isPaused(false), wp(), body_loc(), body_angle(),
 		pos_delta(0,0,0), angle_delta(0), travelTime(get_time()),
-		time(get_time()), TimeStep(FrameTime), vel_xya(0,0,0),
-		target_vel_xya(0,0,0)
+		time(get_time()), TimeStep(FrameTime), slowmo(1.0f),
+		CycleOffset(0), TimeOffset(0), NewCycleOffset(false),
+		vel_xya(0,0,0), target_vel_xya(0,0,0)
 {
 	init(pfile);
 }
@@ -106,6 +115,19 @@ void WalkMC::init(const char* pfile)
 	//	cmds[HeadOffset+TiltOffset].set(.3333,1);
 }
 
+// tss "SmoothWalk" addition follows
+int WalkMC::isDirty()
+{
+  if(isPaused) return false;
+  if((target_vel_xya.x == 0) && (target_vel_xya.y == 0) && (target_vel_xya.z == 0)) {
+	if((vel_xya.x != 0) || (vel_xya.y != 0) || (vel_xya.z != 0)) return true
+;
+	else return false;
+  }
+  return true;
+}
+// tss "SmoothWalk" addition ends
+
 void WalkMC::load(const char* pfile)
 {
   mzero(wp);
@@ -150,7 +172,7 @@ int WalkMC::updateOutputs() {
 	if(!isDirty())
 		return 0;
 	
-  double t = TimeStep / 1000.0;
+  double t = TimeStep * slowmo / 1000;
 
   vel_xya.x = bound(target_vel_xya.x, vel_xya.x-max_accel_xya.x*t, vel_xya.x+max_accel_xya.x*t);
   vel_xya.y = bound(target_vel_xya.y, vel_xya.y-max_accel_xya.y*t, vel_xya.y+max_accel_xya.y*t);
@@ -160,7 +182,24 @@ int WalkMC::updateOutputs() {
   delta.loc.set(vel_xya.x*t,vel_xya.y*t,0);
   delta.angle.set(0,0,vel_xya.z*t);
 
-	time=get_time();
+	time=(int)(get_time()*slowmo);
+
+// tss "SmoothWalk" addition follows
+	// If necessary, we compute a new TimeOffset here.
+	if(NewCycleOffset) {
+		TimeOffset = CycleOffset - time % wp.period;
+		NewCycleOffset = false;
+	}
+
+	// Adjusted time--time adjusted for cycle matching
+	int AdjustedTime = time + TimeOffset;
+
+	// If walking speeds have dwindled down to zero, save our time offset from the beginning of the current walk cycle. Once we start walking again, we start up at the same offset to prevent jerky starts.
+	if((vel_xya.x == 0) && (vel_xya.y == 0) && (vel_xya.z == 0)) {
+		CycleOffset = AdjustedTime % wp.period;
+		NewCycleOffset = true;
+	}
+// tss "SmoothWalk" addition ends
 
 	for(unsigned int frame=0; frame<NumFrames; frame++) {
 		target_vel_xya.rotate_z(-delta.angle.z);
@@ -171,7 +210,9 @@ int WalkMC::updateOutputs() {
 
 		//		cout << "setup,,," << flush;
 
-		double cycle = (double)(time % wp.period) / wp.period;
+// tss "SmoothWalk" modification follows
+		// double cycle = (double)(time % wp.period) / wp.period;
+		double cycle = (double)(AdjustedTime % wp.period) / wp.period;
 		double sway   = wp.sway*cos(2*M_PI*cycle);
 		double hop    = wp.hop*sin(4*M_PI*cycle);
 		double height = wp.body_height;
@@ -206,6 +247,35 @@ int WalkMC::updateOutputs() {
 			if(air){
 				t = (cycle - wp.leg[i].lift_time) / air_f;
 				legpos[i] = legw[i].airpath.eval(t);
+
+// Core tss "SmoothWalk" addition follows
+				// KLUDGY MOD. Goal: reduce the height of the
+				// AIBO's steps as its velocity nears zero.
+				// Since I don't know how most of this code 
+				// works, I'll directly alter legpos[i].z in
+				// the following code to change the z height
+				// with velocity.
+				double velfraction_x = fabs(vel_xya.x / MAX_DX);
+				double velfraction_y = fabs(vel_xya.y / MAX_DY);
+				double velfraction_a = fabs(vel_xya.z / MAX_DA);
+
+				// Choose the biggest velfraction
+				double velfraction =
+				  (velfraction_x > velfraction_y) ?
+				    velfraction_x : velfraction_y;
+				if(velfraction_a > velfraction)
+				  velfraction = velfraction_a;
+
+				// Modify legpos[i].z with velfraction to
+				// shrink it down
+				//velfraction = atan(velfraction * M_PI);
+
+				velfraction-=1;
+				velfraction*=velfraction;
+				velfraction*=velfraction;
+
+				legpos[i].z *= 1-velfraction;
+// Core tss "SmoothWalk" addition ends
 			}else{
 				legpos[i] = (legpos[i] - delta.loc).rotate_z(-delta.angle.z);
 			}
@@ -215,9 +285,10 @@ int WalkMC::updateOutputs() {
 				cmds[LegOffset+i*JointsPerLeg+j][frame].set(nextlegangles[j]);
 		}
 
-		time += TimeStep;
+		// tss "SmoothWalk" modification follows
+		AdjustedTime = time+TimeOffset+(int)(frame*TimeStep*slowmo);
 	}
-
+	
 	for(unsigned int joint=LegOffset; joint<LegOffset+NumLegJoints; joint++)
 		motman->setOutput(this,joint,cmds[joint]);
 
@@ -303,9 +374,16 @@ int save_file(data *arr,int num,const char *filename) {
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.13 $
- * $State: Exp $
- * $Date: 2003/05/01 17:19:29 $
+<<<<<<< WalkMC.cc
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.16 $
+ * $State: Rel $
+ * $Date: 2003/09/12 02:01:44 $
+=======
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.16 $
+ * $State: Rel $
+ * $Date: 2003/09/12 02:01:44 $
+>>>>>>> 1.15
  */
 
