@@ -45,6 +45,8 @@
  *
  *  This portion of the code falls under CMPack's license:
  *  @verbinclude CMPack_license.txt
+ *
+ *  @bug the legs try (briefly) to straighten out when first starting to move
  */
 class WalkMC : public MotionCommand {
 public:
@@ -87,8 +89,12 @@ public:
 	virtual void DoStop();  //!< sends a deactivate LocomotionEvent
 
 	virtual int updateOutputs(); //!< calculates current positions of the paws
-	virtual int isDirty() { return !isPaused && (target_vel_xya.x!=0 || target_vel_xya.y!=0 || target_vel_xya.z!=0); } //!< returns true if we are walking
-	virtual int isAlive() { return true; } //!< always true - never autoprunes
+	
+	//! Returns true if we are walking. This modified isDirty allows the AIBO to slow down to a stop rather than stopping immediately.
+	virtual int isDirty();
+	
+	//! always true - never autoprunes
+	virtual int isAlive() { return true; }
 
 	//! loads parameters from a file (@todo use LoadSave)
 	void load(const char* pfile);
@@ -115,14 +121,20 @@ public:
 	double getSway() { return wp.sway; } //!< gets WalkParam::sway of #wp
 	void setPeriod(long p) { wp.period=p; } //!< sets WalkParam::period of #wp
 	long getPeriod() { return wp.period; } //!< gets WalkParam::period of #wp
+	void setSlowMo(float p) { slowmo=p; } //!< sets slowmo
+	float* getSlowMo() { return &slowmo; } //!< gets slowmo
 
+	WalkParam & getWP() { return wp; }; //!< returns the current walk parameter structure
+	
 	//! takes current leg positions from WorldState and tries to match the point in the cycle most like it
 	void resetLegPos();
 
 	static const float MAX_DX; //!< ==180 mm/sec
 	static const float MAX_DY; //!< ==140 mm/sec
 	static const float MAX_DA; //!< ==1.8 rad/sec
-	static const vector3d max_accel_xya; //!< vector version of MAX_DX,MAX_DY,MAX_DA
+// tss "SmoothWalk" modification follows (actually only comment is changed)
+	// static const vector3d max_accel_xya; //!< vector version of MAX_DX,MAX_DY,MAX_DA
+	static const vector3d max_accel_xya; //!< maximum acceleration of x, y, and a velocity
 
  protected:
 	//! holds current joint commands
@@ -144,9 +156,30 @@ public:
 	double angle_delta; //!< how much we've turned
 	
 	unsigned int travelTime; //!< the time since the last call to setTargetVelocity - handy to check the time we've been traveling current vector
-	int time; //!< time of last call to updateJointCmds()
-	int TimeStep; //!< time to pretend passes between each call to updateJointCmds() - usually RobotInfo::FrameTime, unless you want to make it walk in slow motion (handy sometimes for debugging)
-	
+	int time; //!< time of last call to updateJointCmds() (scaled by slowmo)
+	int TimeStep; //!< time to pretend passes between each call to updateJointCmds() - usually RobotInfo::FrameTime
+	float slowmo; //!< scales time values to make the walk move in slow motion for analysis (or fast forward)
+
+	// tss "SmoothWalk" addition follows
+	/*! The CycleOffset variable is used to ensure that each time the AIBO
+	 *  starts walking, it starts at the same point in the walk cycle as
+	 *  where it stopped. This measure is intended to decrease the amount
+	 *  of jerking (and hence deviation) that occurs when the AIBO starts
+	 *  walking forward and then suddenly stops. */
+	int CycleOffset;
+	/*! Each CycleOffset corresponds to a different TimeOffset once the
+	 *  robot starts walking again. Consider this example: the robot
+	 *  stops 2/3 of the way through the cycle, then starts again 1/3
+	 *  of the way through the cycle on the absolute clock. The time
+	 *  offset to advance the clock to the right part of the cycle is
+	 *  1/3 of a cycle, so we set TimeOffset to 1/3 cycle and add that to
+	 *  every clock value used in the walk code. */
+	int TimeOffset;
+	/*! Every time we stop, we know we'll have a new CycleOffset, and we'll
+	 *  need to compute a new TimeOffset. This boolean says as much. */
+	bool NewCycleOffset;
+// tss "SmoothWalk" addition ends
+
 	vector3d vel_xya; //!< the current velocity we're moving
 	vector3d target_vel_xya; //!< the velocity that was requested
 };
@@ -174,14 +207,15 @@ public:
  * @brief Describes WalkMC, a MotionCommand for walking around
  * @author CMU RoboSoccer 2001-2002 (Creator)
  * @author ejt (ported)
+ * @author PA Gov. School for the Sciences 2003 Team Project - Haoqian Chen, Yantian Martin, Jon Stahlman (modifications)
  * 
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.8 $
- * $State: Exp $
- * $Date: 2003/04/09 03:33:57 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.14 $
+ * $State: Rel $
+ * $Date: 2003/10/07 01:00:40 $
  */
 
 #endif
