@@ -4,6 +4,7 @@
 
 #include <vector>
 #include <string>
+#include "RobotInfo.h"
 
 //!provides global access to system configuration information
 class Config {
@@ -42,14 +43,15 @@ class Config {
 		int gain;             //!< gain
 		int shutter_speed;    //!< shutter speed
 		int resolution;       //!< resolution
-		char thresh[30];      //!< thresholds
-		char colors[30];      //!< colors
+		char thresh[50];      //!< thresholds
+		char colors[50];      //!< colors
 		int raw_port;         //!< port to send raw frames on
 		int rle_port;         //!< port to send RLE frames on
 		int obj_port;         //!< port to send object info on
+    int raw_encoding;     //!< resolution and other details for raw output
       
 		//!constructor
-		vision_config() : white_balance(3), gain(2), shutter_speed(2), resolution(2), thresh(), colors(), raw_port(0), rle_port(0), obj_port(0) {}
+		vision_config() : white_balance(3), gain(2), shutter_speed(2), resolution(2), thresh(), colors(), raw_port(0), rle_port(0), obj_port(0), raw_encoding(0) {}
 	} vision;
 	
 	//!core functionality information
@@ -65,13 +67,15 @@ class Config {
 		int walkControl_port;	   //!< port for receiving walk commands
 		int estopControl_port;	   //!< port for receiving walk commands
     int aibo3d_port;   //!< port for send/receive of joint positions from Aibo 3D GUI
+    int wmmonitor_port; //!< port for monitoring Watchable Memory
 		bool use_VT100;    //!< if true, enables VT100 console codes (currently only in Controller menus - 1.3)
 
 		//!constructor
 		main_config()
 			: console_port(0), stderr_port(0), error_level(0), debug_level(0),
 				verbose_level(0),wsjoints_port(0),wspids_port(0),headControl_port(0),
-				walkControl_port(0),estopControl_port(0),aibo3d_port(0), use_VT100(true)
+				walkControl_port(0),estopControl_port(0),aibo3d_port(0),
+        wmmonitor_port(0), use_VT100(true)
 		{ }
 	} main;
 
@@ -99,6 +103,9 @@ class Config {
 		std::string root;       //!< path on memory stick to "motion" files - for instance, position (.pos) and motion sequence (.mot)
 		char estop_on_snd[50];  //!< sound file to use when e-stop turned on
 		char estop_off_snd[50]; //!< sound file to use when e-stop turned off
+		float max_head_tilt_speed; //!< max speed for the head joints, used by HeadPointerMC; rad/s
+		float max_head_pan_speed; //!< max speed for the head joints, used by HeadPointerMC; rad/s
+		float max_head_roll_speed; //!< max speed for the head joints, used by HeadPointerMC; rad/s
 
 		//!returns an absolute path if @a is relative (to root), otherwise just @a name
 		std::string makePath(std::string name) { 
@@ -106,8 +113,11 @@ class Config {
 		}
 
 		//!constructor
-		motion_config() : root() {
+		motion_config() : root(), max_head_tilt_speed(0), max_head_pan_speed(0), max_head_roll_speed(0) {
 			estop_on_snd[0]=estop_off_snd[0]='\0';
+			max_head_tilt_speed=0;
+			max_head_pan_speed=0;
+			max_head_roll_speed=0;
 		}
 	} motion;
 
@@ -139,6 +149,11 @@ class Config {
 
 	//! call this function when it's time to read the configuration file
 	void readConfig(const char* filename);
+	//! returns the section structure corresponding to the section name given
+  section_t parseSection(const char* key);
+	//! pass the section, item name string, item value string - sets the value and returns pointer to the item changed
+  void* setValue(section_t section, const char *key, const char *value, bool updated=false);
+
 
 protected:
 
@@ -154,10 +169,10 @@ extern Config* config;
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.16 $
- * $State: Exp $
- * $Date: 2003/07/07 04:32:47 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.19 $
+ * $State: Rel $
+ * $Date: 2003/09/07 22:14:19 $
  */
 
 #endif
