@@ -12,6 +12,10 @@ class ReferenceCounter {
  public:
 	//! constructor
 	ReferenceCounter() : references(0),RC_autodelete(true) {}
+	//! copy constructor - uses autodelete setting of @a rc, but references will still start at 0
+	ReferenceCounter(const ReferenceCounter& rc) : references(0),RC_autodelete(rc.RC_autodelete) {}
+	//! assignment operator - does nothing
+	ReferenceCounter& operator=(const ReferenceCounter& rc) {return *this;}
 
 	//! destructor - will std::cout a warning if still has references
 	virtual ~ReferenceCounter() {
@@ -69,10 +73,10 @@ const char* findname(ReferenceCounter* x) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.3 $
- * $State: Exp $
- * $Date: 2003/06/12 18:06:11 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.5 $
+ * $State: Rel $
+ * $Date: 2003/08/21 22:33:00 $
  */
 
 #endif
