@@ -13,6 +13,16 @@ public:
 
 protected:
 	SharedObjectBase() : rcr(NULL) {} //!< constructor, protected because you shouldn't need to create this directly, just a common interface to all templates of SharedObject
+
+	//< destructor, automatically dereferences #rcr
+	virtual ~SharedObjectBase() {
+		//std::cout << "~SharedObjectBase(): rcr->NumberOfReference()==" << rcr->NumberOfReference() << std::endl;
+		if(rcr && rcr->NumberOfReference()>0)
+			rcr->RemoveReference();
+		else
+			std::cout << "WARNING: SharedObjectBase destructed without reference" << std::endl;
+		//std::cout << "~SharedObjectBase()NOW: rcr->NumberOfReference()==" << rcr->NumberOfReference() << std::endl;
+	} 
 	RCRegion * rcr; //!< the pointer to the shared memory region this is in charge of
 	
 private:
@@ -30,32 +40,32 @@ public:
 
 	//! Creates the class with the default constructor
 	SharedObject() : SharedObjectBase() {
-		rcr = new RCRegion(calcsize());
+		rcr=createRCRegion();
 		new (rcr->Base()) MC;
 	}
 	//! Creates the class, passing its constructor t1
 	template<class T1> SharedObject(T1 t1) : SharedObjectBase() {
-		rcr = new RCRegion(calcsize());
+		rcr=createRCRegion();
 		new (rcr->Base()) MC(t1);
 	}
 	//! Creates the class, passing its constructor t1 and t2
 	template<class T1, class T2> SharedObject(T1 t1, T2 t2) : SharedObjectBase(){
-		rcr = new RCRegion(calcsize());
+		rcr=createRCRegion();
 		new (rcr->Base()) MC(t1,t2);
 	}
 	//! Creates the class, passing its constructor t1, t2, and t3
 	template<class T1, class T2, class T3> SharedObject(T1 t1, T2 t2, T3 t3) : SharedObjectBase(){
-		rcr = new RCRegion(calcsize());
+		rcr=createRCRegion();
 		new (rcr->Base()) MC(t1,t2,t3);
 	}
 	//! Creates the class, passing its constructor t1, t2, t3 and t4
 	template<class T1, class T2, class T3, class T4> SharedObject(T1 t1, T2 t2, T3 t3, T4 t4) : SharedObjectBase(){
-		rcr = new RCRegion(calcsize());
+		rcr=createRCRegion();
 		new (rcr->Base()) MC(t1,t2,t3,t4);
 	}
 	//! Creates the class, passing its constructor t1, t2, t3, t4 and t5 - if you need more arguments, just add them
 	template<class T1, class T2, class T3, class T4, class T5> SharedObject(T1 t1, T2 t2, T3 t3, T4 t4, T5 t5) : SharedObjectBase(){
-		rcr = new RCRegion(calcsize());
+		rcr=createRCRegion();
 		new (rcr->Base()) MC(t1,t2,t3,t4,t5);
 	}
 	//@}
@@ -64,13 +74,21 @@ public:
 	MC& operator*() const { return *dataCasted(); } //!< smart pointer to the underlying class
 	MC& operator[](int i) const { return dataCasted()[i]; } //!< smart pointer to the underlying class
 protected:
+	//! creates and returns RCRegion of correct size for current class.  Adds a reference (which is removed in the destructor)
+	static RCRegion * createRCRegion() {
+		RCRegion * r = new RCRegion(calcsize());
+		//std::cout << "createRCRegion(): rcr->NumberOfReference()==" << r->NumberOfReference() << std::endl;
+		r->AddReference();
+		//std::cout << "createRCRegion()NOW: rcr->NumberOfReference()==" << r->NumberOfReference() << std::endl;
+		return r;
+	}
 	MC* dataCasted() const { return static_cast<MC*>(data()); } //!< returns a correctly typed pointer to the object's memory
 
 	//!Calculates the size of the memory region to be used, rounding up to the nearest page size
 	/*! Not sure this is completely necessary, but may be nice.  Of course, this also means even
 	 *  small regions are going to be at least 4K (current page size)  If memory gets tight or we
 	 *  get a lot of little regions floating around, this might be worth checking into */
-	unsigned int calcsize() {
+	static unsigned int calcsize() {
 		size_t size = sizeof(MC);
 		sError error;
 		size_t page_size;
@@ -98,10 +116,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.1 $
- * $State: Exp $
- * $Date: 2003/03/09 07:06:11 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.3 $
+ * $State: Rel $
+ * $Date: 2003/09/12 23:42:12 $
  */
 
 #endif //INCLUDED_SharedObject_h
