@@ -7,8 +7,10 @@
 
 WorldStateSerializer::WorldStateSerializer() : wsJoints(NULL), wsPIDs(NULL) {
   wsJoints=wireless->socket(SocketNS::SOCK_STREAM, 1024, 2048);
+  wireless->setDaemon(wsJoints);
   wireless->listen(wsJoints, config->main.wsjoints_port);
   wsPIDs=wireless->socket(SocketNS::SOCK_STREAM, 1024, 2048);
+  wireless->setDaemon(wsPIDs);
   wireless->listen(wsPIDs, config->main.wspids_port);
 }
 
