@@ -193,8 +193,8 @@ SoundManager::Play(Snd_ID id) {
 		
 		if(sndlist[id].rcr!=NULL)
 			erouter->postEvent(EventBase::audioEGID,playid,EventBase::activateETID,0);
-		return playid;
 	}
+	return playid;
 }
 	
 SoundManager::Play_ID
@@ -370,7 +370,7 @@ SoundManager::CopyTo(OSoundVectorData* data) {
 				char size=srcs.size();
 				//just the first one, set dest
 				for(unsigned int c=0; c<1; c++) {
-					if(ends[c]-srcs[c]>avail) {
+					if((size_t)(ends[c]-srcs[c])>avail) {
 						for(dest=begin;dest<end;dest++) {
 							*dest=(*(char*)srcs[c])/size;
 							srcs[c]++;
@@ -388,7 +388,7 @@ SoundManager::CopyTo(OSoundVectorData* data) {
 				}
 				//the rest, add to dest
 				for(unsigned int c=1; c<srcs.size(); c++) {
-					if(ends[c]-srcs[c]>avail) {
+					if((size_t)(ends[c]-srcs[c])>avail) {
 						for(dest=begin;dest<end;dest++) {
 							*dest+=(*(char*)srcs[c])/size;
 							srcs[c]++;
@@ -407,7 +407,7 @@ SoundManager::CopyTo(OSoundVectorData* data) {
 				short size=srcs.size();
 				//just the first one, set dest
 				for(unsigned int c=0; c<1; c++) {
-					if(ends[c]-srcs[c]>avail) {
+					if((size_t)(ends[c]-srcs[c])>avail) {
 						for(dest=begin;dest<end;dest+=2) {
 							*(short*)dest=(*(short*)srcs[c])/size;
 							srcs[c]+=2;
@@ -425,7 +425,7 @@ SoundManager::CopyTo(OSoundVectorData* data) {
 				}
 				//the rest, add to dest
 				for(unsigned int c=1; c<srcs.size(); c++) {
-					if(ends[c]-srcs[c]>avail) {
+					if((size_t)(ends[c]-srcs[c])>avail) {
 						for(dest=begin;dest<end;dest+=2) {
 							*(short*)dest+=(*(short*)srcs[c])/size;
 							srcs[c]+=2;
@@ -688,10 +688,10 @@ SoundManager::PlayState::PlayState()
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.13 $
- * $State: Exp $
- * $Date: 2003/06/10 00:53:48 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.14 $
+ * $State: Rel $
+ * $Date: 2003/07/25 20:18:08 $
  */
 
 
