@@ -11,6 +11,7 @@
 
 // Additional modifications for Tekkotsu framework
 
+#include "SoundPlay/entry.h"
 #include <OPENR/OPENRAPI.h>
 #include <OPENR/OSyslog.h>
 #include <OPENR/core_macro.h>
@@ -24,14 +25,14 @@
 #include "Events/EventRouter.h"
 
 SoundPlay::SoundPlay()
-	: active(0), eventTranslatorQueueMemRgn(NULL), etrans(), speakerID(oprimitiveID_UNDEF)
+	: active(0), soundManagerMemRgn(NULL), eventTranslatorQueueMemRgn(NULL), etrans(), speakerID(oprimitiveID_UNDEF)
 {
-	for (int i = 0; i < SOUND_NUM_BUFFER; i++)
+	for (unsigned int i = 0; i < SOUND_NUM_BUFFER; i++)
 		region[i] = 0;
 }
 
 OStatus
-SoundPlay::DoInit(const OSystemEvent& event)
+SoundPlay::DoInit(const OSystemEvent&)
 {
 	//OSYSDEBUG(("SoundPlay::DoInit()\n"));
 
@@ -65,7 +66,7 @@ SoundPlay::DoInit(const OSystemEvent& event)
 }
 
 OStatus
-SoundPlay::DoStart(const OSystemEvent& event)
+SoundPlay::DoStart(const OSystemEvent&)
 {
 	//OSYSDEBUG(("SoundPlay::DoStart()\n"));
 
@@ -76,10 +77,12 @@ SoundPlay::DoStart(const OSystemEvent& event)
 }
 
 OStatus
-SoundPlay::DoStop(const OSystemEvent& event)
+SoundPlay::DoStop(const OSystemEvent&)
 {
 	//OSYSDEBUG(("SoundPlay::DoStop()\n"));
 
+	sndman->StopPlay();
+
 	DISABLE_ALL_SUBJECT;
 	DEASSERT_READY_TO_ALL_OBSERVER;
 
@@ -87,7 +90,7 @@ SoundPlay::DoStop(const OSystemEvent& event)
 }
 
 OStatus
-SoundPlay::DoDestroy(const OSystemEvent& event)
+SoundPlay::DoDestroy(const OSystemEvent&)
 {
 	for(unsigned int i=0; i<config->sound.preload.size(); i++)
 		sndman->ReleaseFile(config->sound.preload[i].c_str());
@@ -188,7 +191,7 @@ SoundPlay::NewSoundVectorData()
 	 */
 	size_t soundUnitSize = config->sound.sample_rate*config->sound.sample_bits/8*SoundBufferTime/1000;
 
-	for (int i = 0; i < SOUND_NUM_BUFFER; i++) {
+	for (unsigned int i = 0; i < SOUND_NUM_BUFFER; i++) {
 		result = OPENR::NewSoundVectorData(1, soundUnitSize,&soundVecDataID, &soundVecData);
 		if (result != oSUCCESS) {
 			OSYSLOG1((osyslogERROR, "%s : %s %d","SoundPlay::NewSoundVectorData()","OPENR::NewSoundVectorData() FAILED", result));
@@ -243,7 +246,7 @@ SoundPlay::InitRegion(unsigned int size) {
 RCRegion*
 SoundPlay::FindFreeRegion()
 {
-	for (int i = 0; i < SOUND_NUM_BUFFER; i++)
+	for (unsigned int i = 0; i < SOUND_NUM_BUFFER; i++)
 		if (region[i]->NumberOfReference() == 1)
 			return region[i];
 	return 0;
@@ -266,9 +269,9 @@ SoundPlay::FindFreeRegion()
  * implied warranties of fitness for a particular purpose.
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.7 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:41 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.9 $
+ * $State: Rel $
+ * $Date: 2003/10/01 23:03:03 $
  */
 
