@@ -63,6 +63,9 @@ class SoundPlay : public OObject {
 
 	OPrimitiveID   speakerID;  //!< ID returned to system after opening SPEAKER_LOCATOR
 	RCRegion*      region[SOUND_NUM_BUFFER]; //!< holds references to shared regions holding sound clips
+
+	SoundPlay(const SoundPlay&); //!< don't call
+	SoundPlay& operator=(const SoundPlay&); //!< don't call
 };
 
 /*! @file
@@ -82,10 +85,10 @@ class SoundPlay : public OObject {
  * implied warranties of fitness for a particular purpose.
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.3 $
- * $State: Exp $
- * $Date: 2003/04/09 03:33:57 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.4 $
+ * $State: Rel $
+ * $Date: 2003/07/25 20:18:08 $
  */
 
 #endif // SoundPlay_h_DEFINED
