@@ -15,10 +15,10 @@
  * implied warranties of fitness for a particular purpose.
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.2 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:41 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.3 $
+ * $State: Rel $
+ * $Date: 2003/07/25 20:18:08 $
  */
 
 #ifndef WAV_h_DEFINED
@@ -72,6 +72,9 @@ private:
     byte*      dataStart;
     byte*      dataEnd;
     byte*      dataCurrent;
+
+		WAV(const WAV&); //!< don't call
+		WAV& operator=(const WAV&); //!< don't call
 };
 
 #endif // WAV_h_DEFINED
