@@ -20,14 +20,18 @@ Vision *vision=NULL;
 using namespace mathutils;
 using namespace VisionEventNS;
 
-Vision::Vision()
+Vision::Vision() : frameTimestamp(0UL), frame_count(0), cmap(NULL), tmap(NULL),
+                   rmap(NULL), rmap2(NULL), reg(NULL), width(0), height(0),
+                   max_width(0), max_height(0), max_runs(0), max_regions(0),
+                   num_colors(0), num_runs(0), num_regions(0), body_angle(0.0),
+                   body_height(100.0), vis_markers(0), obj_info(NULL),
+                   imageLayer(ofbkimageLAYER_H), vser(NULL)
 {
   initialize();
-  setCameraParam();
   vser=new VisionSerializer();
 }
 
-void Vision::setCameraParam()
+void Vision::setCameraParams()
 {
   static OPrimitiveID fbkID = 0;
       
@@ -60,136 +64,121 @@ void Vision::setCameraParam()
   }
 }
 
-void Vision::initialize()
+void Vision::setResolution()
 {
-  int num_y,num_u,num_v;
-  int size;
-  num_tmaps=1;
-  int result;
-
-  obj_info=new ObjectInfo;
-
   switch(config->vision.resolution) {
-    case 1:
-      width=344;
-      height=288;
+    case 2:
+      width=88;
+      height=72;
+      imageLayer=ofbkimageLAYER_M;
       break;
     case 3:
-      width=86;
-      height=72;
+      width=44;
+      height=36;
+      imageLayer=ofbkimageLAYER_L;
       break;
     default:
-      width=172;
+      width=176;
       height=144;
+      imageLayer=ofbkimageLAYER_H;
       break;
   }
 
   max_width  = width;
   max_height = height;
 
-  // Load color information
-  num_colors =
-  CMVision::LoadColorInformation(color,MAX_COLORS,config->vision.colors);
-  if(num_colors > 0){
-    printf("  Loaded %d colors.\n",num_colors);
-  }else{
-    printf("  ERROR: Could not load color information.\n");
-  }
-
-  // Set up threshold
-  size = 1 << (bits_y + bits_u + bits_v);
-  num_y = 1 << bits_y;
-  num_u = 1 << bits_u;
-  num_v = 1 << bits_v;
-
-  cur_tmap = 0;
-  memset(tmap,0,sizeof(tmap));
-  for(int i=0; i<num_tmaps; i++) {
-#ifdef PLATFORM_APERIOS
-  result = NewRegion(size, reinterpret_cast<void**>(&tmap[i]));
-  if (result != sSUCCESS)
-    printf("Unable to allocate tmap buffer %d of size %d\n",i,size);
-#else
-  tmap[i] = new cmap_t[size];
-#endif
-  memset(tmap[i],0,size*sizeof(cmap_t));
-  }
-
-  for(int i=0; i<num_tmaps; i++) {
-    char tmapfile[256];
-    if(i==0)
-      sprintf(tmapfile,"%s",config->vision.thresh);
-    else
-      sprintf(tmapfile,"%s%d",config->vision.thresh,i);
-    if(!CMVision::LoadThresholdFile(tmap[i],num_y,num_u,num_v,tmapfile)) {
-      printf("  ERROR: Could not load threshold file '%s'.\n",tmapfile);
-    }
-    int remapped=CMVision::CheckTMapColors(tmap[i],num_y,num_u,num_v,num_colors,0);
-    printf("remapped %d colors in threshold file '%s'\n",remapped,tmapfile);
-  }
-
-  // Allocate map structures
-  max_width  = width;
-  max_height = height;
-  size = width * height;
+  int size = width * height;
   max_runs = size / MIN_EXP_RUN_LENGTH;
   max_regions = size / MIN_EXP_REGION_SIZE;
   size = max_width * max_height;
+
+  if (cmap!=NULL) { DeleteLarge(cmap); cmap=NULL; }
   NewLarge(&cmap,size+1); // +1 to store EncodeRuns terminator value
   if(!cmap) {
     cout << "Couldn't allocate cmap\n\xFF" << endl;
     *((long *)0xDEADCC44)=1;
   }
+  if (rmap!=NULL) { DeleteLarge(rmap); rmap=NULL; }
   NewLarge(&rmap,max_runs);
   if(!rmap) {
     cout << "Couldn't allocate rmap\n\xFF" << endl;
     *((long *)0xDEAD7744)=1;
   }
+  if (rmap2!=NULL) { DeleteLarge(rmap2); rmap2=NULL; }
   NewLarge(&rmap2,max_runs);
   if(!rmap2) {
     cout << "Couldn't allocate rmap2\n\xFF" << endl;
     *((long *)0xDEAD7745)=1;
   }
+  if (reg!=NULL) { DeleteLarge(reg); reg=NULL; }
   NewLarge(&reg,max_regions);
   if(!reg) {
     cout << "Couldn't allocate reg\n" << endl;
     *((long *)0xDEAD7E66)=1;
   }
+}
+
+void Vision::setColors()
+{
+  color_names.clear();
+  num_colors =
+    CMVision::LoadColorInformation(color,MAX_COLORS,config->vision.colors,
+                                   color_names);
+  if(num_colors > 0){
+    printf("  Loaded %d colors.\n",num_colors);
+  }else{
+    printf("  ERROR: Could not load colors file:%s\n", config->vision.colors);
+  }
+
+  int num_y,num_u,num_v;
+  int size = 1 << (bits_y + bits_u + bits_v);
+  num_y = 1 << bits_y;
+  num_u = 1 << bits_u;
+  num_v = 1 << bits_v;
+
+  memset(tmap,0,size*sizeof(cmap_t));
+
+  if(!CMVision::LoadThresholdFile(tmap,num_y,num_u,num_v,
+                                  config->vision.thresh)) {
+    printf("  ERROR: Could not load threshold file '%s'.\n",
+           config->vision.thresh);
+  }
+  int remapped=CMVision::CheckTMapColors(tmap,num_y,num_u,num_v,num_colors,0);
+  printf("remapped %d colors in threshold file '%s'\n",
+         remapped, config->vision.thresh);
+}
+
+int Vision::getColor(const char* color) {
+  hash_map<const char*, int, hash<const char*>, hashcmp_eqstr>::iterator i;
+  i=color_names.find(color);
+  if (i==color_names.end()) return -1;
+  return i->second;
+}
+
+void Vision::initialize()
+{
+  int result;
+  int size = 1 << (bits_y + bits_u + bits_v);
+
+  obj_info=new ObjectInfo;
+
+  setResolution();
+
+  // Set up threshold
 
-  body_angle=0.0;
-  body_height=100.0;
-  head_angles[0]=head_angles[1]=head_angles[2]=0.0;
-/*
-  // initialize output stuff
-  encodeBuf = NULL;
-  encoder = NULL;
-  // Always init
-  //if(config.spoutConfig.dumpVisionRLE!=0) {
-  //if(config.spoutConfig.dumpVisionRLE) {
-  // body position (5 floats) + image size*3 chars(value, x, length) + stop chars
-  // body position (5 floats) + image size*3 chars(y, u, v) + stop chars
 #ifdef PLATFORM_APERIOS
-  NewRegion(5*4+176*144*3+2,(void **)&encodeBuf);
-  if(encodeBuf==NULL)
-    printf("Null vision rle encode buf\n");
-  else
-    encoder=new SPOutVisionEncoder;
-  //}
+  result = NewRegion(size, reinterpret_cast<void**>(&tmap));
+  if (result != sSUCCESS)
+    printf("Unable to allocate tmap buffer of size %d\n",size);
+#else
+  tmap = new cmap_t[size];
 #endif
 
-  visionColorAreaStream = NULL;
-  visionRawStream       = NULL;
-  visionRLEStream       = NULL;
-  visionObjStream       = NULL;
+  setColors();
 
-  outCountRaw = 0;
-  outCountRLE = 0;
 
-  //printf("Done initializing vision.\n");
-*/
-  frameTimestamp = 0UL;
-  frame_count=0;
   initializeEventSpecs();
+  setCameraParams();
 }
 
 void Vision::initializeEventSpecs() {
@@ -266,27 +255,20 @@ bool Vision::generateEvent(int vevent, double conf, int cenX, int cenY) {
 
 bool Vision::close()
 {
-  for(int i=0; i<num_tmaps; i++) {
-    delete[] tmap[i];
-  }
-  delete(cmap);
-  delete(rmap);
-  delete(reg);
+  DeleteLarge(tmap);
+  DeleteLarge(cmap);
+  DeleteLarge(rmap);
+  DeleteLarge(rmap2);
+  DeleteLarge(reg);
 
-  memset(tmap,0,sizeof(tmap));
+  tmap = NULL;
   cmap = NULL;
   rmap = NULL;
+  rmap2 = NULL;
   reg  = NULL;
 
   max_width  = 0;
   max_height = 0;
-/*
-#ifdef PLATFORM_APERIOS
-  DeleteRegion(encodeBuf); // don't care about error
-#else
-  delete[] encodeBuf;
-#endif
-  delete encoder;*/
 
   return(true);
 }
@@ -349,7 +331,7 @@ bool Vision::findHand(VObject *hand, VisionObjectInfo *hand_info)
   int n;
   double conf;
 
-  skin=&color[COLOR_SKIN];
+  skin=&color[getColor("skin")];
 
   region *or_reg; // hand region(s)
 
@@ -378,8 +360,8 @@ bool Vision::findHand(VObject *hand, VisionObjectInfo *hand_info)
 }
 
 bool Vision::findBall(int ball_color, VObject *ball,VisionObjectInfo *ball_info) {
-  if ((ball_color==COLOR_RED && vevent_spec[RedBallSID].listeners==0)
-      ||(ball_color==COLOR_PINK && vevent_spec[PinkBallSID].listeners==0)) return false;
+  if ((ball_color==getColor("red") && vevent_spec[RedBallSID].listeners==0)
+      ||(ball_color==getColor("pink") && vevent_spec[PinkBallSID].listeners==0)) return false;
 
   static const bool debug_ball = false;
   static const bool debug_conf = false;
@@ -445,21 +427,21 @@ bool Vision::findBall(int ball_color, VObject *ball,VisionObjectInfo *ball_info)
               conf0,conf_square_bbox,conf_area,conf_area_bonus,conf);
     }
     
-
+/*
     if(conf > ball->confidence) {
       if(debug_ball &&
        (frame_cnt == 0 ||
         frame_cnt == 1)) {
-/*        printf("%s ball n%d cen (%f,%f) area %d bbox (%d,%d)-(%d,%d) conf %f\n", (ball_color==COLOR_PINK)?"Pink":"Orange",
+        printf("%s ball n%d cen (%f,%f) area %d bbox (%d,%d)-(%d,%d) conf %f\n", (ball_color==COLOR_PINK)?"Pink":"Orange",
                 n,or_reg->cen_x,or_reg->cen_y,or_reg->area,
                 or_reg->x1,or_reg->y1,or_reg->x2,or_reg->y2,
-                conf);*/
+                conf);
       }
 
       int sx[2],sy[2]; // scan bounding coordinates;
       bool edge_x[2],edge_y[2]; // true if scan coordinate went off edge
       static const int scan_distance = 3;
-      static int color_cnts[MAX_COLORS];
+      static int color_cnts[num_colors];
       int scan_pixels;
       int good_value;
     
@@ -495,21 +477,15 @@ bool Vision::findBall(int ball_color, VObject *ball,VisionObjectInfo *ball_info)
       }
 
       int non_robot_fringe=0;
-      non_robot_fringe += 5*color_cnts[COLOR_BLUE ];
-/*      non_robot_fringe += 3*color_cnts[COLOR_GRAY ];
-      non_robot_fringe -= 2*color_cnts[COLOR_YELLOW];
-      non_robot_fringe += 3*color_cnts[COLOR_BLUE  ];*/
-      non_robot_fringe -=   color_cnts[COLOR_GREEN   ];
+      non_robot_fringe += 5*color_cnts[getColor("blue")];
+      non_robot_fringe -=   color_cnts[getColor("green")];
 
       conf_red_v_area = 1 + non_robot_fringe / or_reg->area;
       conf_red_v_area = bound(conf_red_v_area,0.0,1.0);
       
       good_value = 0;
-      good_value += 2*color_cnts[COLOR_BLUE ];
-      good_value += 3*color_cnts[COLOR_GREEN]/2;
-/*      good_value += 2*color_cnts[COLOR_GRAY ];
-      good_value -=   color_cnts[COLOR_YELLOW]/2;
-      good_value += 2*color_cnts[COLOR_BLUE  ];*/
+      good_value += 2*color_cnts[getColor("blue")];
+      good_value += 3*color_cnts[getColor("green")]/2;
 
       green_f = std::max(good_value+1,1) / (scan_pixels + 1.0);
       green_f = bound(green_f,0.0,1.0);
@@ -519,21 +495,10 @@ bool Vision::findBall(int ball_color, VObject *ball,VisionObjectInfo *ball_info)
         conf0 *
         conf_square_bbox *
         conf_area *
-        conf_red_v_area *
-        conf_green +
-        conf_area_bonus;
+        + conf_area_bonus;
     
       if(conf > 1.0) conf = 1.0;
-/*
-      if(debug_ball &&
-         frame_cnt == 0) {
-        printf(" conf red_v_area %f conf' %f good_value %d g %d w %d r %d b %d y %d scan_pixels %d green_f %f\n",
-                conf_red_v_area,conf,good_value,
-                color_cnts[COLOR_GREEN],color_cnts[COLOR_WHITE],color_cnts[COLOR_RED],color_cnts[COLOR_BLUE],color_cnts[COLOR_YELLOW],
-                scan_pixels,green_f);
-      }
-*/
-    }
+    }*/
     
     if(conf > ball->confidence) {
       /*
@@ -593,8 +558,7 @@ bool Vision::findBall(int ball_color, VObject *ball,VisionObjectInfo *ball_info)
     or_reg = or_reg->next;
     n++;
   }
-  
-  return (ball_color==COLOR_RED)?generateEvent (RedBallSID, ball->confidence, ball_info->reg->cen_x, ball_info->reg->cen_y):generateEvent(PinkBallSID,ball->confidence,ball_info->reg->cen_x,ball_info->reg->cen_y);
+  return (ball_color==getColor("red"))?generateEvent (RedBallSID, ball->confidence, ball_info->reg->cen_x, ball_info->reg->cen_y):generateEvent(PinkBallSID,ball->confidence,ball_info->reg->cen_x,ball_info->reg->cen_y);
 }
 
 bool Vision::findThing(VObject *thing, VisionObjectInfo *thing_info) {
@@ -670,9 +634,9 @@ bool Vision::findMarkers() {
 
   region *or_reg, *gr_reg, *pu_reg;
 
-  or_reg = color[COLOR_ORANGE].list;
-  gr_reg = color[COLOR_BGREEN].list;
-  pu_reg = color[COLOR_PURPLE].list;
+  or_reg = color[getColor("orange")].list;
+  gr_reg = color[getColor("bgreen")].list;
+  pu_reg = color[getColor("purple")].list;
 
   region* marker_regs[9];
   int num_regs=0;
@@ -794,7 +758,6 @@ bool Vision::findGesture(VisionObjectInfo *hand_info) {
         if (rmap[i].parent==parent
             && rmap[i].width>5
             && rmap[i].x > xl+10) {
-//          rmap[i].color=COLOR_RED;
           thumbsup++;
           thumbx+=xl+(rmap[i].x-xl)/2;
         } else {
@@ -804,7 +767,6 @@ bool Vision::findGesture(VisionObjectInfo *hand_info) {
         if (rmap[i].parent==parent
             && rmap[i].width>5) {
           r=i;
-//          rmap[i].color=COLOR_ORANGE;
           xl=rmap[i].x+rmap[i].width;
         }
       }
@@ -830,15 +792,18 @@ bool Vision::runHighLevelVision(ObjectInfo *obj_info) {
     vobj_info[obj_idx].reg = NULL;
   }
 
-  findMarkers();
-  bool rball_exist=findBall(COLOR_RED,&obj_info->rball,&vobj_info[RBALL]);
-  bool pball_exist=findBall(COLOR_PINK,&obj_info->pball,&vobj_info[PBALL]);
+
+//  findMarkers();
+//  bool rball_exist=findBall(getColor("red"),&obj_info->rball,&vobj_info[RBALL]);
+  if (getColor("red")>=0)
+    bool pball_exist=findBall(getColor("red"),&obj_info->pball,&vobj_info[PBALL]);
+  /*
   bool hand_exist=findHand(&obj_info->hand,&vobj_info[HAND]);
   if (hand_exist
       && !(rball_exist && isIn(vobj_info[RBALL].reg,vobj_info[HAND].reg))
       && !(pball_exist && isIn(vobj_info[PBALL].reg,vobj_info[HAND].reg)))
       // hand exists and hand is not holding ball
-    findGesture(&vobj_info[HAND]);
+    findGesture(&vobj_info[HAND]);*/
   return true;
 }
 
@@ -858,7 +823,7 @@ bool Vision::thresholdImage(CMVision::image_idx<rgb> &img) {
 }
 
 bool Vision::thresholdImage(CMVision::image_yuv<const uchar> &img) {
-  CMVision::ThresholdImageYUVPlanar<cmap_t,CMVision::image_yuv<const uchar>,const uchar,bits_y,bits_u,bits_v>(cmap,img,tmap[cur_tmap]);
+  CMVision::ThresholdImageYUVPlanar<cmap_t,CMVision::image_yuv<const uchar>,const uchar,bits_y,bits_u,bits_v>(cmap,img,tmap);
 
   return true;
 }
@@ -945,41 +910,10 @@ bool Vision::runLowLevelVision(image &img)
 #endif
 
 //   CMVision::CreateRunIndex(yindex,rmap,num_runs);
-/*
-#ifdef PLATFORM_APERIOS
-  // output color area if desired
-  if(config.spoutConfig.dumpVisionColorArea!=0) {
-    outCountColorArea = (outCountColorArea + 1) % config.spoutConfig.dumpVisionColorArea;
-    if(outCountColorArea==0) {
-      sendColorArea();
-    }
-  }
-#endif
-
-#ifdef PLATFORM_APERIOS
-  // output raw frames if desired
-  if(config.spoutConfig.dumpVisionRaw!=0) {
-    outCountRaw = (outCountRaw + 1) % config.spoutConfig.dumpVisionRaw;
-    if(outCountRaw==0) {
-      sendRawImage();
-    }
-  }
-#endif
-
-#ifdef PLATFORM_APERIOS
-  // output RLE if desired
-  if(config.spoutConfig.dumpVisionRLE!=0) {
-    outCountRLE = (outCountRLE + 1) % config.spoutConfig.dumpVisionRLE;
-    if(outCountRLE==0) {
-      sendRLEImage();
-    }
-  }
-#endif
-*/
   return(true);
 }
 
-bool Vision::processFrame(const uchar *data_y, const uchar *data_u, const uchar *data_v, int width, int height) {
+bool Vision::processFrame(const uchar *data_y, const uchar *data_u, const uchar *data_v, int width, int height, int skip) {
   frameTimestamp = get_time();
   frame_count++;
 
@@ -989,7 +923,8 @@ bool Vision::processFrame(const uchar *data_y, const uchar *data_u, const uchar
 
   img.width=width;
   img.height=height;
-  img.row_stride=3*width;
+  //img.row_stride=3*width;
+  img.row_stride=skip+width;
 
   bool ok=true;
 
@@ -1016,17 +951,6 @@ int WritePPM(char *filename,rgb *img,int width,int height)
   return(wrote);
 }
 
-int Vision::setThreshold(int threshold_id) {
-  if(threshold_id < 0 || threshold_id >= num_tmaps) {
-    return -1;
-  } else {
-    int old_threshold;
-    old_threshold = cur_tmap;
-    cur_tmap = threshold_id;
-    return old_threshold;
-  }
-}
-
 bool Vision::saveThresholdImage(char *filename)
 {
   rgb *buf;
@@ -1041,99 +965,21 @@ bool Vision::saveThresholdImage(char *filename)
 
   return(wrote > 0);
 }
-/*
-void Vision::sendRawImage() {
-#ifdef PLATFORM_APERIOS
-  if(encodeBuf!=NULL && 
-     encoder  !=NULL && 
-     visionRawStream!=NULL) {
-    int out_size=0;
-    out_size=encoder->encodeVisionRaw(encodeBuf,
-                                      body_angle,body_height,
-                                      head_angles[0],head_angles[1],head_angles[2],
-                                      img);
-    if(!visionRawStream->writeBinary(encodeBuf,out_size,frameTimestamp))
-      printf("problem writing raw image\n");
-  } else {
-    if(encoder==NULL)
-      printf("NVEnc\n");
-    else if(encodeBuf==NULL)
-      printf("NVEncBuf\n");
-    else
-      printf("NVRawStream\n");
-  }
-#endif
 
-  outCountRaw = 0;
-}
-
-void Vision::sendRLEImage() {
-#ifdef PLATFORM_APERIOS
-  if(encodeBuf!=NULL && 
-     encoder  !=NULL && 
-     visionRLEStream!=NULL) {
-    int out_size=0;
-#ifdef ENABLE_JOIN_NEARBY
-    out_size=encoder->encodeVisionRLE(encodeBuf,
-                                      body_angle,body_height,
-                                      head_angles[0],head_angles[1],head_angles[2],
-                                      num_runs-2,rmap+1);
-#else
-    out_size=encoder->encodeVisionRLE(encodeBuf,
-                                      body_angle,body_height,
-                                      head_angles[0],head_angles[1],head_angles[2],
-                                      num_runs,rmap);
-#endif
-    visionRLEStream->writeBinary(encodeBuf,out_size,frameTimestamp);
-  } else {
-    if(encoder==NULL)
-      printf("NVEnc\n");
-    else if(encodeBuf==NULL)
-      printf("NVEncBuf\n");
-    else
-      printf("NVRLEStream\n");
-  }
-#endif
-
-  outCountRLE = 0;
-}
-
-void Vision::sendColorArea() {
-  if(encodeBuf!=NULL && 
-     visionColorAreaStream!=NULL) {
-    int out_size=0;
-    uchar *buf;
-    buf = encodeBuf;
-    SPOutEncoder::encodeAs<uchar>(&buf,(uchar)num_colors);
-    for(int color_idx=0; color_idx<num_colors; color_idx++) {
-      SPOutEncoder::encodeAs<ulong>(&buf,(ulong)color[color_idx].total_area);
-    }
-    out_size = buf - encodeBuf;
-    visionColorAreaStream->writeBinary(encodeBuf,out_size,frameTimestamp);
-  } else {
-    if(encodeBuf==NULL)
-      printf("NVEncBuf\n");
-    else
-      printf("NVColorAreaStream\n");
-  }
-}*/
-
-namespace VisionInterface {
-/*  void SendRawImage(Vision *vision) {
-    vision->sendRawImage();
-  }
-
-  void SendRLEImage(Vision *vision) {
-    vision->sendRLEImage();
-  }*/
-
-  void WriteThresholdImage(Vision *vision, char *filename) {
-    vision->saveThresholdImage(filename);
-  }
-
-  int SetThreshold(Vision *vision,int threshold_id) {
-    return vision->setThreshold(threshold_id);
-  }
+vector3d Vision::getPixelDirection(double x, double y) {
+/*  vector3d img_pixel_dir; // direction vector of pixel in image coordinates
+                                                                                
+  img_pixel_dir.set((x+.5-width/2.0),(height/2.0-(y+.5))*YPixelSize,FocalDist);
+                                                                                
+  vector3d robot_pixel_dir; // direction vector of pixel in robot coordinates
+  robot_pixel_dir =
+    camera_dir  *img_pixel_dir.z +
+    camera_up   *img_pixel_dir.y +
+    camera_right*img_pixel_dir.x;
+                                                                                
+  robot_pixel_dir = robot_pixel_dir.norm();
+                                                                                
+  return robot_pixel_dir;*/
 }
 
 /*! @file
@@ -1144,8 +990,8 @@ namespace VisionInterface {
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.11 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:41 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.15 $
+ * $State: Rel $
+ * $Date: 2003/10/10 05:38:25 $
  */
