@@ -15,6 +15,9 @@ private:
 	//! encodes the original camera image
   void encodeVisionRaw(char *buf,CMVision::image_yuv<const uchar> &img,
                        int scale);
+  //! special encoding of the original camera image
+  void encodeVisionRaw_YhalfUVquarter(char *buf,
+      CMVision::image_yuv<const uchar> &img);
 	//! encodes the RLE processed image
   void encodeVisionRLE(char *buf,int num_runs,run *runs);
 	//! helper function for encodeVisionRLE, encodes one run length
@@ -34,11 +37,11 @@ private:
  * 
  * @verbinclude CMPack_license.txt
  *
- * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.2 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:41 $
+ * $Author: alokl $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.3 $
+ * $State: Rel $
+ * $Date: 2003/07/28 06:53:10 $
  */
 
 #endif
