@@ -20,6 +20,10 @@
 #include "Visiondefines.h"
 
 #include "cmv_types.h"
+#include <ext/hash_map>
+
+struct hashcmp_eqstr { bool operator()(const char* s1, const char* s2) const
+                     { return strcasecmp(s1, s2) == 0; } };
 
 namespace CMVision{
 
@@ -78,11 +82,8 @@ inline num top_bit(num n)
 
 //==== Main Library Functions ======================================//
 
-// this code is currently broken, it seems to cause rare crashes !!!
-//#define ENABLE_JOIN_NEARBY
-//#define ALOK_JOIN
+#define REMOVE_NOISE
 
-#ifndef ALOK_JOIN
 template <class rle_t,class tmap_t>
 int EncodeRuns(rle_t *rle,tmap_t *map,int width,int height,int max_runs)
 // Changes the flat array version of the thresholded image into a run
@@ -92,6 +93,13 @@ int EncodeRuns(rle_t *rle,tmap_t *map,int width,int height,int max_runs)
   tmap_t m,save;
   tmap_t *row;
   int x,y,j,l;
+ 
+#ifdef REMOVE_NOISE
+  int lastcolor;
+  int noise;
+  int noise_back;
+#endif
+  
   rle_t r;
 
   r.next = 0;
@@ -100,15 +108,7 @@ int EncodeRuns(rle_t *rle,tmap_t *map,int width,int height,int max_runs)
   save = map[0];
 
   j = 0;
-#ifdef ENABLE_JOIN_NEARBY
-  // store black row before image
-  r.color = 0;
-  r.width = width;
-  r.x = 0;
-  r.y = -1;
-  r.parent = j;
-  rle[j++] = r;
-#endif
+
   for(y=0; y<height; y++){
     row = &map[y * width];
 
@@ -120,6 +120,12 @@ int EncodeRuns(rle_t *rle,tmap_t *map,int width,int height,int max_runs)
     r.y = y;
 
     x = 0;
+
+#ifdef REMOVE_NOISE
+    lastcolor=0;
+    noise=0;
+    noise_back=0;
+#endif
     while(x < width){
       m = row[x];
       r.x = x;
@@ -127,103 +133,43 @@ int EncodeRuns(rle_t *rle,tmap_t *map,int width,int height,int max_runs)
       l = x;
       while(row[x] == m) x++;
 
-      if(m!=0 || x>=width){
-	r.color = m; 
-	r.width = x - l;
-	r.parent = j;
-	rle[j++] = r;
-
-        // printf("run (%d,%d):%d %d\n",r.x,r.y,r.width,r.color);
-
-	if(j >= max_runs) {
-          row[width] = save;
-          return(j);
+#ifdef REMOVE_NOISE
+      if (x - l > 4) {
+        if (noise>=4) {
+          j=j-noise_back;
+          lastcolor=0;
         }
-      }
-    }
-  }
-
-#ifdef ENABLE_JOIN_NEARBY
-  // store black row after image
-  r.color = 0;
-  r.width = width;
-  r.x = 0;
-  r.y = height;
-  r.parent = j;
-  rle[j++] = r;
-#endif
-
-  return(j);
-}
-#endif
-
-#ifdef ALOK_JOIN
-template <class rle_t,class tmap_t>
-int EncodeRuns(rle_t *rle,tmap_t *map,int width,int height,int max_runs)
-{
-  tmap_t m,save;
-  tmap_t *row;
-  int x,y,j,l,l1;
-  rle_t r;
-  bool entry=false;
-
-  r.next = 0;
-
-  // initialize terminator restore
-  save = map[0];
-
-  j = 0;
-  for(y=0; y<height; y++){
-    row = &map[y * width];
-
-    // restore previous terminator and store next
-    // one in the first pixel on the next row
-    row[0] = save;
-    save = row[width];
-    row[width] = MAX_COLORS;
-    r.y = y;
-
-    x = 0;
-    while(x < width){
-      m = row[x];
-      r.x = x;
-
-      l = x;
-
-      if (x==0) {
-        l1=l;
-        while (row[x]==m) x++;
-        while (((x-l1<4)||(m==0 && x-l1<9 )) && x<width) {
-          l1=x;
-          m=row[x];
-          while (row[x]==m) x++;
-        }
-        if (m!=0) entry=true;
+        noise=0; 
+        noise_back=0;
       } else {
-        while (row[x]==m) x++;
+        noise++;
+        if (m) noise_back++;
       }
+#endif
 
-      if (x<width && ((m<MAX_COLORS && x-l<4) || (m==0 && x-l<9))) {
-        if (entry) rle[j-1].width=rle[j-1].width+x-l;
-      } else if(m!=0 || x>=width){
-      	r.color = m; 
-       	r.width = x - l;
-       	r.parent = j;
-       	rle[j++] = r;
+      if(m!=0 || x>=width){
+        r.color = m; 
+        r.width = x - l;
+        r.parent = j;
+        rle[j++] = r;
 
-        // printf("run (%d,%d):%d %d\n",r.x,r.y,r.width,r.color);
-
-       	if(j >= max_runs) {
+        if(j >= max_runs) {
           row[width] = save;
           return(j);
         }
       }
+#ifdef REMOVE_NOISE
+      else if (!m && lastcolor && x-l<5) {
+        rle[j-1].width+=x-l;
+      }
+      
+      lastcolor=m;
+#endif
     }
   }
 
   return(j);
 }
-#endif
 
 template <class rle_t,class tmap_t,class edge_t>
 int EncodeRunsUseEdges(rle_t *rle,tmap_t *map,edge_t *edge_map,int width,int height,int max_runs)
@@ -1112,8 +1058,10 @@ int find(data *arr,int start,int end,data key)
   return(end);
 }
 
+using namespace __gnu_cxx;
+
 template <class color_class_state_t>
-int LoadColorInformation(color_class_state_t *color,int max,const char *filename)
+int LoadColorInformation(color_class_state_t *color,int max,const char *filename, hash_map<const char*, int, hash<const char*>, hashcmp_eqstr> &color_names)
 {
   char buf[512];
   FILE *in;
@@ -1156,6 +1104,7 @@ int LoadColorInformation(color_class_state_t *color,int max,const char *filename
 	  color[idx].color.green = g;
 	  color[idx].color.blue  = b;
 	  color[idx].name = strdup(name);
+    color_names[color[idx].name]=idx;
 	  if(idx >= num) num = idx+1;
 	} else {
  	  printf("Options error: %2d (%3d %3d %3d) '%s' %d\n",
