@@ -83,6 +83,7 @@ Socket::flush()
 			sendData=writeData;
 			sendSize=writeSize;
 			wireless->blockingSend(sock);
+			writeSize=0;
 		}
 	}
 }
@@ -165,9 +166,9 @@ Socket::read(byte * /*buf*/, int /*size*/)
  * @author alokl (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.13 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:41 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.15 $
+ * $State: Rel $
+ * $Date: 2003/10/01 23:03:43 $
  */
 
