@@ -58,9 +58,10 @@ public:
 			sendSize(0), recvSize(0), writeSize(0), readSize(0),
 			tx(false), rx(false), sendBuffer(), recvBuffer(), sendData(NULL),
 			recvData(NULL), readData(NULL), writeData(NULL), server_port(0),
-		rcvcbckfn(NULL), textForward(false), textForwardBuf(NULL), forwardSock(NULL)
+      rcvcbckfn(NULL), textForward(false), textForwardBuf(NULL),
+      forwardSock(NULL), daemon(false)
 	{ }
-  ~Socket() {} //!< destructor
+  virtual ~Socket() {} //!< destructor
 
   //! use getWriteBuffer to get a memory address to write bytes to, for
   //! subsequent writing to a connection.
@@ -170,7 +171,7 @@ public:
    */
   void flush();
 
-private:
+protected:
 	//@{
 	//!private ALOKL_TODO
   TransportType_t trType;
@@ -193,9 +194,11 @@ private:
   bool textForward;
 	char* textForwardBuf;
 	Socket * forwardSock;
+
+  bool daemon;
 	//@}
  
-private:
+protected:
   Socket(const Socket&); //!< copy constructor, don't call
   Socket& operator= (const Socket&); //!< assignment operator, don't call
 };
@@ -208,10 +211,10 @@ extern Socket* serr;  //!< the standard tekkotsu error output (default port 1000
  * @author alokl (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.12 $
- * $State: Exp $
- * $Date: 2003/06/13 03:23:05 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.15 $
+ * $State: Rel $
+ * $Date: 2003/09/25 15:32:14 $
  */
 
 #endif
