@@ -15,13 +15,15 @@ using namespace SocketNS;
 Wireless *wireless=NULL;
 
 Wireless::Wireless ()
-  : ipstackRef(), myOID(), sock_num(0)
+  : ipstackRef(), myOID(), freeSockets()
 {
   ipstackRef = antStackRef("IPStack");
   WhoAmI(&myOID);
 
-  for (int sock = 0; sock < WIRELESS_MAX_SOCKETS; sock++) {
+  sockets[0]=new DummySocket(0);
+  for (int sock = 1; sock < WIRELESS_MAX_SOCKETS; sock++) {
     sockets[sock]=NULL;
+    freeSockets.push_back(sock);
   }
 }    
 
@@ -37,8 +39,10 @@ Socket* Wireless::socket(TransportType_t ttype)
 
 Socket* Wireless::socket(TransportType_t ttype, int recvsize, int sendsize)
 {
-  if (sock_num >= WIRELESS_MAX_SOCKETS
-      || (recvsize + sendsize) <= 256) return NULL;
+  if (freeSockets.empty()
+      || (recvsize + sendsize) <= 256) return sockets[0];
+  int sock_num=freeSockets.front();
+  freeSockets.pop_front();
 
   sockets[sock_num]=new Socket(sock_num);
   sockets[sock_num]->trType=ttype;
@@ -48,7 +52,7 @@ Socket* Wireless::socket(TransportType_t ttype, int recvsize, int sendsize)
   // setup send buffer
   antEnvCreateSharedBufferMsg sendBufferMsg(sendsize*2);
   sendBufferMsg.Call(ipstackRef, sizeof(sendBufferMsg));
-  if (sendBufferMsg.error != ANT_SUCCESS) return NULL;
+  if (sendBufferMsg.error != ANT_SUCCESS) return sockets[0];
   
   sockets[sock_num]->sendBuffer = sendBufferMsg.buffer;
   sockets[sock_num]->sendBuffer.Map();
@@ -58,7 +62,7 @@ Socket* Wireless::socket(TransportType_t ttype, int recvsize, int sendsize)
   // setup receive buffer
   antEnvCreateSharedBufferMsg recvBufferMsg(recvsize*2);
   recvBufferMsg.Call(ipstackRef, sizeof(recvBufferMsg));
-  if (recvBufferMsg.error != ANT_SUCCESS) return NULL;
+  if (recvBufferMsg.error != ANT_SUCCESS) return sockets[0];
   
   sockets[sock_num]->recvBuffer = recvBufferMsg.buffer;
   sockets[sock_num]->recvBuffer.Map();
@@ -68,13 +72,13 @@ Socket* Wireless::socket(TransportType_t ttype, int recvsize, int sendsize)
   sockets[sock_num]->readData=sockets[sock_num]->recvData+recvsize;
   sockets[sock_num]->writeData=sockets[sock_num]->sendData+sendsize;
 
-  return sockets[sock_num++]; 
+  return sockets[sock_num]; 
 }
 
 int Wireless::listen(int sock, int port)
 {
   if (port<=0 || port>=65535
-      || sock<0 || sock>=sock_num
+      || sock<=0 || sock>=WIRELESS_MAX_SOCKETS || sockets[sock]==NULL
       || sockets[sock]->state != CONNECTION_CLOSED) return -1;
   
   sockets[sock]->server_port=port;
@@ -126,7 +130,7 @@ int Wireless::listen(int sock, int port)
 int Wireless::connect(int sock, const char* ipaddr, int port)
 {
   if (port<=0 || port>=65535
-      || sock<0 || sock>=sock_num
+      || sock<=0 || sock>=WIRELESS_MAX_SOCKETS || sockets[sock]==NULL
       || sockets[sock]->state != CONNECTION_CLOSED) return -1;
   
   sockets[sock]->init();
@@ -185,6 +189,7 @@ Wireless::ConnectCont(void *msg)
   }
   
   sockets[sock]->state = CONNECTION_CONNECTED;
+  if (sockets[sock]->rcvcbckfn) { receive(sock); }  //Thanks to Andrew Cristina <acristin@cs.uno.edu>, et. al. for bug fix
 }
 
 void
@@ -204,7 +209,7 @@ Wireless::BindCont(void *msg)
 void
 Wireless::send(int sock)
 {
-  if (sock<0 || sock>=sock_num
+  if (sock<=0 || sock>=WIRELESS_MAX_SOCKETS || sockets[sock]==NULL
       || sockets[sock]->state != CONNECTION_CONNECTED
       || sockets[sock]->sendSize <= 0) return;
 
@@ -235,10 +240,15 @@ Wireless::SendCont(void* msg)
     sockets[sock]->flush();
 }
 
+/*! @bug This doesn't actually seem to block until the message is
+ *	fully sent... a crash immediately after this will still cause a
+ *	line or two to be dropped.  This is still less dropped than
+ *	regular send, but doesn't do much good for debugging until we fix
+ *	this. (if we can...) */
 void
 Wireless::blockingSend(int sock)
 {
-  if (sock<0 || sock>=sock_num
+  if (sock<=0 || sock>=WIRELESS_MAX_SOCKETS || sockets[sock]==NULL
       || sockets[sock]->state != CONNECTION_CONNECTED
       || sockets[sock]->sendSize <= 0) return;
 
@@ -257,7 +267,7 @@ Wireless::blockingSend(int sock)
 void
 Wireless::setReceiver(int sock, int (*rcvcbckfn) (char*, int) )
 {
-  if (sock<0 || sock>=sock_num) return;
+  if (sock<=0 || sock>=WIRELESS_MAX_SOCKETS || sockets[sock]==NULL) return;
 
   sockets[sock]->rcvcbckfn=rcvcbckfn;
 }
@@ -265,7 +275,7 @@ Wireless::setReceiver(int sock, int (*rcvcbckfn) (char*, int) )
 void
 Wireless::receive(int sock)
 {
-  if (sock<0 || sock>=sock_num
+  if (sock<=0 || sock>=WIRELESS_MAX_SOCKETS || sockets[sock]==NULL
       || sockets[sock]->state != CONNECTION_CONNECTED) return;
   
   TCPEndpointReceiveMsg receiveMsg(sockets[sock]->endpoint,
@@ -282,7 +292,7 @@ Wireless::receive(int sock)
 void
 Wireless::receive(int sock, int (*rcvcbckfn) (char*, int) )
 {
-  if (sock<0 || sock>=sock_num
+  if (sock<=0 || sock>=WIRELESS_MAX_SOCKETS || sockets[sock]==NULL
       || sockets[sock]->state != CONNECTION_CONNECTED) return;
 
   sockets[sock]->rcvcbckfn=rcvcbckfn;
@@ -321,6 +331,15 @@ Wireless::close(int sock)
   if (sockets[sock]->state == CONNECTION_CLOSED ||
       sockets[sock]->state == CONNECTION_CLOSING) return;
 
+  if (!(sockets[sock]->server_port>0 && sockets[sock]->daemon)) {
+    sockets[sock]->recvBuffer.UnMap();
+    antEnvDestroySharedBufferMsg receiveBufferMsg(sockets[sock]->recvBuffer);
+    receiveBufferMsg.Call(ipstackRef, sizeof(antEnvDestroySharedBufferMsg));
+    sockets[sock]->sendBuffer.UnMap();
+    antEnvDestroySharedBufferMsg sendBufferMsg(sockets[sock]->sendBuffer);
+    sendBufferMsg.Call(ipstackRef, sizeof(antEnvDestroySharedBufferMsg));
+  }
+
   TCPEndpointCloseMsg closeMsg(sockets[sock]->endpoint);
   closeMsg.continuation = (void*)sock;
 
@@ -337,10 +356,14 @@ Wireless::CloseCont(void* msg)
   int sock = (int)(closeMsg->continuation);
 
   sockets[sock]->state = CONNECTION_CLOSED;
-  if (sockets[sock]->server_port>0) {
+  if (sockets[sock]->server_port>0
+      && sockets[sock]->daemon) {
     // recycle if server
-    if (sockets[sock]->server_port>0)
-      listen(sock, sockets[sock]->server_port);
+    listen(sock, sockets[sock]->server_port);
+  } else {
+    delete(sockets[sock]);
+    sockets[sock]=NULL;
+    freeSockets.push_back(sock);
   }
 }
 
@@ -351,9 +374,9 @@ Wireless::CloseCont(void* msg)
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.7 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:41 $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.14 $
+ * $State: Rel $
+ * $Date: 2003/10/07 01:01:22 $
  */
 
