@@ -8,8 +8,11 @@
 #include <ant.h>
 //#include "MMCombo/def.h"
 #include "Socket.h"
+#include "DummySocket.h"
+#include <list>
 
 using namespace SocketNS;
+using namespace __gnu_cxx;
 
 //! Tekkotsu wireless class
 /*!
@@ -62,7 +65,9 @@ public:
   int connect(int sock, const char* ipaddr, int port);
 	//! sets receiver callback for a socket
   void setReceiver(int sock, int (*rcvcbckfn) (char*, int) );
-	//! closes a socket
+  //! sets the socket to be a daemon (recycles on close)
+  void setDaemon(int sock, bool val=true) { sockets[sock]->daemon=val; }
+	//! closes and destroys non server, daemon sockets
   void close(int sock);
 
   //@{
@@ -82,6 +87,8 @@ public:
     { setReceiver(sobj.sock, rcvcbckfn); }
   void setReceiver(Socket *sobj, int (*rcvcbckfn) (char*, int) )
     { setReceiver(sobj->sock, rcvcbckfn); }
+  void setDaemon(Socket &sobj, bool val=true) { setDaemon(sobj.sock, val); }
+  void setDaemon(Socket *sobj, bool val=true) { setDaemon(sobj->sock, val); }
   int listen(Socket &sobj, int port) { return listen(sobj.sock, port); } 
   int listen(Socket *sobj, int port) { return listen(sobj->sock, port); } 
   int connect(Socket &sobj, const char* ipaddr, int port)
@@ -123,7 +130,7 @@ private:
   antStackRef ipstackRef;
   OID myOID;
   Socket* sockets[WIRELESS_MAX_SOCKETS];
-  int sock_num;
+  list<int> freeSockets;
 	//@}
 
 private:
@@ -140,11 +147,11 @@ extern Wireless* wireless;
  * 
  * @verbinclude CMPack_license.txt
  *
- * $Author: ejt $
- * $Name: tekkotsu-1_4 $
- * $Revision: 1.12 $
- * $State: Exp $
- * $Date: 2003/06/12 23:41:41 $
+ * $Author: alokl $
+ * $Name: tekkotsu-1_5 $
+ * $Revision: 1.14 $
+ * $State: Rel $
+ * $Date: 2003/09/21 19:43:41 $
  */
 
 #endif // Wireless_h_DEFINED
