@@ -25,6 +25,7 @@
 #include "Shared/WorldState.h"
 #include "Vision/Vision.h"
 #include "Wireless/Wireless.h"
+#include "Shared/Config.h"
 
 // include WorldModel2 particulars
 #include "FastSLAM/afsMain.h"
@@ -203,10 +204,8 @@ void WorldModel2::disableKludge(unsigned int kludge)
   // Marker events--for FastSLAM
 void WorldModel2::enableMarkers()
 {
-    // We enable marker vision events
-  vision->enableEvents(VisionEventNS::MarkersSID);
-    // We even listen to them if we're not moving
-    // note: also checks for indicator value of 0 of movingSince
+	// We even listen to them if we're not moving
+	// note: also checks for indicator value of 0 of movingSince
   if(movingSince && !moving)
     erouter->addListener(this,EventBase::visionEGID, VisionEventNS::MarkersSID);
   enabledMarkers = true;
